%
%               FILE DESCRIBING THE JPL MODIS DAILY AQUA SST DATA SET (MY04MDN1 and MY04MDD1)

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
Cat_m_File = 'ffcsquery';
% this ensures the following will be included in the manifest
AdditionalFunctions = 'apply_sst_quality';

% VARIABLES -- OPTIONAL
CatalogServer = 'http://dods.jpl.nasa.gov/dods-bin/nph-dods/catalogs/modis/L3/daily/04km/daily-04km-SST.dat';
Additional_FileServer_Constraints = 'platform&platform="aqua"';

axes_order = [2 1 0 0];

% VARIABLES -- REQUIRED
LonRange = [-180 180];
LatRange = [90 -90];
TimeRange = [2002+11*30/365+13/365 2005];
DepthRange = [0 0];
Resolution = 4.9;

DataName = 'AQUA Daily SST (MY04MDD1 and MY04MDN1 - JPL';
SelectableVariables = str2mat('Sea_Temp');
DodsName = 'sst_mean';

% note: DataNull is applied *before* scaling
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
DataNull(5) = {0};
DataScale = [NaN NaN; NaN NaN; NaN NaN; NaN NaN; -300.0 0.01];

Data_Use_Policy = sprintf('%s%s%s', ...
  'There are quality fields associate with these SST fields. ',...
  'You can access them either via the GUI by selecting ',...
  'the "AQUA Daily SST Quality" data set or by running ',...
  'apply_sst_quality from the Matlab prompt after you have ',...
  'acquired the SST data. You will be prompted for the ',...
  'range of request numbers - Rnn to Rmm. A new array, ',...
  'prefixed with Q instead of R, in which all pixels ',...
  'flagged as questionable are set to nan will be created.',...
  'The procedure for running apply_sst_quality is described ',...
  'in the text field for this data set as well.');

Acknowledge = sprintf('%s\n', [ '  ']);

% COMMENTS
Comments = sprintf('%s\n', ...
'                                     ACQUA Daily SST (MY04MDD1 and MY04MDN1)',...
' ',...
' Primary site: Goddard Space Flight Center',...
'  Mirror site: Jet Propulsion Laboratory',...
' ',...
' Daily mean 4.88 km SST fields in degrees C. Two fields per day, one for ascending passes and one for ',...
' descending passes.',...
' ',...
'            GENERAL DESCRIPTION',...
' ',...
'    SST derived from the Moderate-resolution Imaging Spectroradiometer (MODIS) instruments aboard the NASA ',...
' Terra and Aqua satellites represent a new milestone in high sensitivity thermal infrared remote sensing. Data ',...
' are currently available globally at 4 km, 36 km and 1 degree resolutions with daily, weekly and monthly time ',...
' intervals in HDF-EOS files. These data are the latest science quality Level 3 files processed by the Modis ',...
' Adaptive Processing System (MODAPS) and distributed by the Goddard Distributed Active Archive Center (GDAAC) ',...
' located at the NASA Goddard Space Flight Center. PO.DAAC is acting as a mirror site for Level 3 MODIS ocean ',...
' SST products.',...   
' ',...
' There are quality fields associate with these SST fields. You can access them either via the GUI by selecting ',...
' the "AQUA Daily SST Quality" data set or by running apply_sst_quality from the Matlab prompt after you have ',...
' acquired the SST data. You will be prompted for the range of request numbers - Rnn to Rmm. A new array, ',...
' prefixed with Q instead of R, in which all pixels flagged as questionable are set to nan will be created.',...
' The procedure for running apply_sst_quality is described the text field for this data set as well.',...
' ',...
' See the MODIS Ocean Data Processing site for a general discussion of the processing:',...
'     http://picasso.oce.orst.edu/ORSOO/MODIS/code/',...
' ',...
' For a description of the processing algorithms used see: http://modis.gsfc.nasa.gov/data/atbd/atbd_mod25.pdf',...
' ',...
' The JPL site for these data is: http://podaac.jpl.nasa.gov/modis/');
