%
%               FILE DESCRIBING THE Esbensen Kushnir Climatologies at PMEL
%                            Sea-Air Temperature Difference 

% The preceding empty line is important.

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL

% VARIABLES -- OPTIONAL
Server = 'http://ferret.wrc.noaa.gov/cgi-bin/nph-nc/data/Esbensen_Kushnir.nc';

% VARIABLES -- REQUIRED
LonRange = [20.000 380.000];
LatRange = [-90.000 90.000];
TimeRange = [1800 str2num(datestr(date,10))];
DepthRange = [0.0 0.0];
DepthUnits = '';
Resolution = 495.0;

% force time axis to correct day [Y M D H M S]
Time_Offset = [0 0 -1 0 0 0];

DataName = 'Surface - Esbensen Kushnir Fluxes - PMEL';

SelectableVariables = str2mat('Temp_Diff','Up_Radiation', ...
'Latent_Heat','Spec_Hum_Diff','Downward_Heat','Sea_Temp', ...
'Sensible_Heat','Insolation','Spec_Humidity', str2mat('Cloud_Cover', ...
'Down_Radiation','Pressure','Wind_Speed'));
DodsName = str2mat('SAT','FUL','FLH','SAH','FDH','SST','FSH', ...
    'FSR','AH', str2mat('CLD','FDR','SLP','SPD'));

Acknowledge = sprintf('%s\n\n%s', ...
    [ 'The principal investigators in the production of this dataset ',...
      'are S. Esbensen and Y. Kushnir. The data were provided by the ',...
      'Ferret development group of the Thermal Modeling and Analysis ',...
      'Project at NOAA''s Pacific Marine Environmental Laboratory in ',...
      'Seattle Washington (PMEL: http://www.pmel.noaa.gov  Ferret: ',...
      'http://ferret.pmel.noa.gov) and accessed via the National ',...
      'Virtual Ocean Data System (NVODS: ',...
      'http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citation: Esbensen, S. K. & Kushnir, Y. 1981:  The heat budget ',...
      'of the global ocean: An ', ...
      'atlas based on estimates from surface marine observations. Climatic ',...
      'Research Institute, Oregon State University. Report No. 29. ',...
      'http://ATS.ORST.EDU:80/Faculty/esbensen/tropical/CRI_Report_29.html']);
  
% COMMENTS
Comments1 =sprintf('%s\n', ...
'                    Esbensen-Kushnir Heat Budget Climatology at PMEL', ...
'    ', ...
'    The Heat Budget of the Global Ocean, published by Steven Esbensen and Yochanan ', ...
'    Kushnir of the Climate Research Institute at Oregon State University, in 1981. ', ...
'    To calculate the heat budget components, bulk formulas parameterizing the heat ', ...
'    flux mechanisms were applied to monthly mean values of basic surface variables.', ...
'     ', ...
'    Data sources for the basic variables were a global climatology of surface ', ...
'    marine meteorological observations prepared by the by the NCDC and the ', ...
'    Berliand and Strokina cloudiness atlas. ', ...
'    ', ...
'    The atlas includes maps of the monthly mean distributions of the calculated ', ...
'    heat budget components and of the basic variables used in the calculation. ', ...
'    All the fields have a uniform spatial resolution and are presented on a ', ...
'    regular 4degx5deg. grid.  Heat budget components include: ', ...
'    ', ...
'        Net Upward Longwave Flux   Units: W/M2   VariableName: FUL ', ...
'        Latent Heat Flux   Units: W/M2   VariableName: FLH ', ...
'        Sea-Air Specific Humidity Difference   Units: GR/KG   VariableName: SAH ', ...
'        Net Downward Heat Flux   Units: W/M2   VariableName: FDH ', ...
'        Sea Surface Temperature   Units: Deg C   VariableName: SST ', ...
'        Sea-Air Temperature Difference   Units: Deg C   VariableName: SAT ', ...
'        Sensible Heat Flux   Units: W/M2   VariableName: FSH ', ...
'        Available Solar Radiation   Units: W/M2   VariableName: FSR ', ...
'        Specific Humidity   Units: GR/KG   VariableName: AH', ...
'        Cloudiness   Units: Fraction of Sky Cover   VariableName: CLD ', ...
'        Net Downward Radiative Flux   Units: W/M2   VariableName: FDR ', ...
'        Sea Level Pressure   Units: MB   VariableName: SLP ', ...
'        Surface Wind Speed   Units: M/S   VariableName: SPD ', ...
'    ', ...
'    Note:  The origin of the data grid (indicies (1,1)) has a lat/long value of ', ...
'    (-90,20), and a corresponding terminal point (indices (42,76)) corresponding ', ...
'    to (90,375).  Longitude values span 360 degrees, from 20-380 degrees.', ...
'    ', ...
'    References:', ...
'    ', ...
'    Esbensen, S. K. & Kushnir, Y. 1981:  The heat budget of the global ocean: An ', ...
'        atlas based on estimates from surface marine observations. Climatic ', ...
'        Research Institute, Oregon State University. Report No. 29.', ...
'        URL: http://ATS.ORST.EDU:80/Faculty/esbensen/tropical/CRI_Report_29.html');
Comments2 = sprintf('%s\n', ...
'   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date:1800 ', ...
'         Ending_Date:1998 ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:20.0 ', ...
'              East Bounding Coordinate:380.0 ', ...
'              South Bounding Coordinate:-90.00 ', ...
'              North Bounding Coordinate:+90.00 ', ...
'    Units:  Degrees Centigrade ', ...
'    Resolution: .01 deg. C ', ...
'    Accuracy: 1 deg. C ', ...
'   ', ...
'    Point_of_Contact (Science) = ', ...
'         Address: ', ...
'               Steve K. Esbensen ', ...
'               College of Oceanic and Atmospheric Sciences', ...
'               104 Ocean Admin Bldg', ...
'               Oregon State University ', ...
'               Corvallis, Oregon 97331-5503', ...
'               USA ', ...
'               Phone: (541) 737-5687 ', ...
'         Electronic Mail Address:INTERNET > esbensen@ats.orst.edu',...
'               Yochanon Kushnir ', ...
'               104-C Oceanography', ...
'               Lamont-Doherty Earth Observatory', ...
'               Columbia University', ...
'               Palisades, New York 10964', ...
'               USA ', ...
'               Phone: (914) 365-8669', ...
'         Electronic Mail Address:INTERNET > kushnir@ldeo.columbia.edu',...
'    Point_of_Contact (Data Provision) = ', ...
'         Address: ', ...
'               Kevin O''Brien ', ...
'               NOAA/PMEL', ...
'               7600 Sand Point Way NE', ...
'               Seattle, Washington 98115-0070', ...
'               USA ', ...
'               Telephone: (206) 526-6751', ...
'         Electronic Mail Address:INTERNET > ferret@pmel.noaa.gov');



Comments = [Comments1 Comments2];

%
% $Id: eskusat.m,v 1.8 2004/04/17 19:50:19 dbyrne Exp $

% $Log: eskusat.m,v $
% Revision 1.8  2004/04/17 19:50:19  dbyrne
% *** empty log message ***
%
% Revision 1.7  2003/11/10 20:05:15  dbyrne
%
%
% Temp hack to identify arrays, minor bug fixes to time axis data.  dbyrne 2003/11/10
%
% Revision 1.6  2003/07/10 21:21:46  dbyrne
%
%
% Changed 'DODS' to 'NVODS'.  dbyrne 2003/07/10
%
% Revision 1.5  2002/08/15 03:57:46  dan
% Added axes_order to avoid pop-up window.
%
% Revision 1.4  2002/02/08 23:30:09  dan
% Removed Nlat, Nlon and variable names. GUI will use das/dds.
% Changed time range to go to present
%
% Revision 1.3  2001/01/18 19:35:44  dbyrne
%
%
% datarange is no longer in use.  changed datanull to cell in many cases.
% -- dbyrne 01/01/17
%
% Revision 1.2  2000/11/20 19:07:49  dbyrne
% *** empty log message ***
%
% Revision 1.2  2000/11/20 16:11:53  root
% *** empty log message ***
%
% Revision 1.1  2000/05/31 22:59:19  root
% *** empty log message ***
%
% Revision 1.15  2000/04/12 01:19:28  root
% Modifications to support toolbox.
%
% Revision 1.14  1999/09/02 18:27:23  root
% *** empty log message ***
%
% Revision 1.11  1999/05/13 03:09:54  dbyrne
%
%
% Added Acknowledge and Data_Use_Policy to archive.m.  Fixed getxxx functions
% to use dodsmsg instead of stdout for errors/info.  Made ChangeLog so that it's
% in Emacs format.  All changes for release 3.0.0 -- dbyrne 99/05/12
%
% Revision 1.13  1999/05/13 01:24:15  root
% Added Acknowledge and Data_Use Policy.  Fixed some bugs.  Changed any
% messages to use to use 'dodsmsg' script instead of just displaying to stdout.
%
% Revision 1.12  1999/03/04 13:13:26  root
% All changes since AGU week.
%
% Revision 1.10  1998/12/15 19:17:08  jimg
% Modified 'DataName' to include variable type information.
%
% Revision 1.9  1998/11/18 19:57:01  dbyrne
%
%
% Second try.  Bug fixes to jpl pathfinder data, changed names of
% Reynolds datasets to clarify that one is a climatology and one is not.
%
% Revision 1.11  1998/11/05 16:01:52  root
% Changed LonVector and LatVector to be used if no Lon returned and tried the update function.
% DataScale and DataNull should now be optional!
%
% Revision 1.6  1998/09/14 01:32:53  dbyrne
% Elminated an inconsistency whereby the depth variable was not scaled
% and had no DataNull etc.  Added check for empty variables to plotscript.m
%
% Revision 1.10  1998/09/13 19:33:23  root
% updated DataNull &c.
%
% Revision 1.9  1998/09/13 19:21:22  root
% Eliminated an inconsistency in DataScale, DataRange, and DataNull, that
% Depth was not included!
%
% Revision 1.8  1998/09/11 08:16:07  dbyrne
% Longitude ranges were messed up in every archive.m file except the
% two I wrote myself.  To eliminate future confusion, 'LLon' 'Llat',
% 'Rlon' and 'Ulat' etc are being eliminated in favor of two-component
% vectors LonRange LatRange TimeRange DepthRange.
%
% Revision 1.7  1998/09/10 21:14:06  dbyrne
% Fixed some small bugs.
%
% Revision 1.6  1998/09/09 20:12:16  dbyrne
% Changing variable names to stay within 14 characters.
%
% Revision 1.5  1998/09/09 19:42:04  dbyrne
% Now serves ALL Esbensen-Kushnir meteorological variables.
%
% Revision 1.4  1998/09/09 07:57:36  dbyrne
% replaced Data_Scale with DataScale, Data_Null with DataNull, and Data_Range
% with DataRange for consistency with other variables in the archive.m files.
%
% Revision 1.3  1998/09/09 07:40:20  dbyrne
% Replaced getrectangular with getrectg
%
% Revision 1.2  1998/09/09 07:34:21  dbyrne
% Eliminating ReturnedVariables
%
% Revision 1.1  1998/05/17 14:18:03  dbyrne
% *** empty log message ***
%
% Revision 1.2  1997/12/08 17:30:30  tom
% fixed 'nc' to correct 'nph-nc'
%
% Revision 1.1.1.1  1997/09/22 14:13:54  tom
% Imported Matlab GUI sources to CVS
%
