function [locate_x, locate_y, depths, tmp_times, URLinfo, urllist, ...
      url, dods_err, dods_err_msg] = gridcat(baseurl, ranges, georange, ...
    dodsfields, URLinfo, archive, xystride)

% Note that this should have contingency for > 4 dims, with other dims
% being something we can't display in the browser: use a popup window
% showing dimension name and possible number of selections.
% this will mean that GEOPOS goes away (or becomes greater than 4);
% and axnames and ax must do the same.

% PCC added the following 2/2/02
% Source the .m file with suggested names to search for for map
% vectors


% flag to turn on/off supplementary messages.  Default is OFF
% this is first set in browse.m
global dods_expert_mode

% ARRAYS EXECUTE THIS PART -----------------------------------------------
[X_Names, Y_Names, Z_Names, A_Names, T_Names] = AxisNames;

depths = [];
tmp_times  = [];
locate_x = [];
locate_y = [];
urllist = '';
url = '';
start_time = NaN;
timebase = '';
axnames = '';
axunits = [];
data_name = [];
data_scale = [];
data_units = [];
data_null = [];
data_server = [];
data_type = '';
gridsize = [];
Nlon = [];
Nlat = [];
Ntime = [];
Ndepth = [];
xmap = [];
ymap = [];
zmap = [];
tmap = [];
dods_err = 0;
dods_err_msg = '';
reversedepth = 0;

% geopos: the positions of those axes displayed on the GUI,
% x-, y-, z-, t-axis.
geopos = zeros(1,4);

% construct value field names for matlab and for the DAP
field1 = deblank(dodsfields(1,:));
newfield1 = dods_dbk(dodsfields(1,:));

if exist(archive) ~= 2
  dodsmsg(['Problem reading dataset metadata ' get_archive '.m'])
  return
else
  eval(archive)
end

% a URL arriving as an input argument overrides info that might have
% been in the archive.m file.  Dbyrne 2002/09/19
if ~isempty(baseurl)
  Server = baseurl;
end

cache_status = 'get_new';
if isstruct(URLinfo)
  if ~isempty(strmatch('data_name',fieldnames(URLinfo),'exact'))
    if ~isempty(URLinfo.data_name)
      % we have a valid cache of metadata
      cache_status = 'use_old';
    end
  end
else
  URLinfo = mkurlinfo;
end

switch cache_status
  case 'get_new' % GET METADATA FROM DAS/DDS
    % get the DAS.  This needs to be done whether or not we are
    % using the archive file because even with the archive file
    % we don't know the ORDER in which the maps must be used.
    for n = size(Server,1):-1:1
      server = deblank(Server(n,:)); 
      % modification to outwit Matlab v6.5 -- dbyrne 2003/06/04
      try; [DAS] = loaddods('-A -e', server); catch; end
      
      if dods_err
	str = sprintf('%s%s', ...
	    [ 'Error accessing the dataset DAS. Unable ', ...
	      'to process request'], dods_err_msg);
	dods_err_msg = str;
	return
      end

      % descend to data level
      newfield = dods_dbk(dodsfields(n,:));
      % added by dbyrne 2002/09/30
      % the PREFERRED match is to find the desired field at the top
      % level of the DAS.
      structname = '';
      if isfield(DAS, newfield)
	if isstruct(eval([ 'DAS.' newfield]))
	  structname = [ 'DAS.' newfield];
	end
      end
      
      % IF a match is not found at the top level, flatten the
      % structure and look for a match in the next level down
      % and so on.
      if isempty(structname)
	% this is used for HDF files like MO04MD_Terra.m
	struct_string = epstruct(DAS, 'DAS');
	num_elements = size(struct_string,1);
	
	% Note the addition of dots on either side of newfield which
	% was required to prevent false matches, for example, finding
	% 'SAT', in 'DAS.KSAT'.
	
	for ipcc = 1:num_elements
	  nn = strfind(struct_string{ipcc}, [ '.' newfield '.']);
	  if ~isempty(nn)
	    structname = struct_string{ipcc};
	    l = max(strfind(structname, '.'));
	    structname = structname(1:l-1);
	    % once a match is found, stop looking!
	    break
	  end
	end
    
	if isempty(nn)
	  dods_err = 1;
	  dods_err_msg = sprintf('%s%s%s','Not able to identify variable ', ...
	      newfield, ' in dataset DAS/DDS.');
	  return
	end
      end

      % Get offset, scale factor and missing value for dependent
      % variables.  Do it in a non-case-sensitive way.  This should
      % work for both grids and arrays, I think.
      l = max(strfind(structname, '.'));
      topname = structname(1:l-1);
      nvars = length(fieldnames(eval(topname)));
      data_name = [fieldnames(eval(topname)); data_name];
      data_null = [cell(nvars,1); data_null];
      data_scale = [cell(nvars,1); data_scale];
      [data_scale(1:nvars)] = deal({[0 1]});
      data_units = [cell(nvars,1); data_units];
      data_server = [cell(nvars,1); data_server];
      data_server(1:nvars) = deal({server});

      for i = 1:nvars
	fl = [ topname '.' deblank(data_name{i})];
	
	if isstruct(eval(fl))
	  % set scaling
	  flnames = fieldnames(eval(fl));
	  k1 = strmatch('add_offset',lower(flnames));
	  if length(k1) > 1
	    k1 = strmatch('add_offset',lower(flnames),'exact');
	  elseif isempty(k1)
	    k1 = strmatch('intercept',lower(flnames));
	    if length(k1) > 1
	      k1 = strmatch('intercept',lower(flnames),'exact');
	    end
	  end
	
	  k2 = strmatch('scale_factor',lower(flnames));
	  if length(k2) > 1
	    k2 = strmatch('scale_factor',lower(flnames),'exact');
	  elseif isempty(k2)
	    k2 = strmatch('slope',lower(flnames));
	    if length(k2) > 1
	      k2 = strmatch('slope',lower(flnames),'exact');
	    end
	  end

	  if ~isempty(k1) & ~isempty(k2)
	    data_scale{i} = [getfield(eval(fl),flnames{k1}) ...
		  getfield(eval(fl),flnames{k2})];
	  elseif ~isempty(k1) & isempty(k2)
	    data_scale{i} = [getfield(eval(fl),flnames{k1}) 1];
	  elseif isempty(k1) & ~isempty(k2)
	    data_scale{i} = [0 getfield(eval(fl),flnames{k2})];
	  else
	    data_scale{i} = [0 1];
	  end

	  % get nulls
	  k1 = strmatch('missing_value',lower(flnames));
	  if ~isempty(k1)
	    if length(k1) > 1
	      k1 = strmatch('missing_value',lower(flnames),'exact');
	    end
	    data_null{i} = getfield(eval(fl),flnames{k1});
	  end
	  k1 = strmatch('ml__fillvalue',lower(flnames));
	  if ~isempty(k1)
	    if length(k1) > 1
	      k1 = strmatch('ml__fillvalue',lower(flnames),'exact');
	    end
	    data_null{i} = [data_null{i}, getfield(eval(fl),flnames{k1})];
	  end
	
	  % get units
	  k1 = strmatch('units',lower(flnames));
	  if ~isempty(k1)
	    if length(k1) > 1
	      k1 = strmatch('units',lower(flnames),'exact');
	    end
	    data_units{i} = getfield(eval(fl),flnames{k1});
	  end
	end % end if isstruct
      end % for i = 1:nvars
    end % end of loop through multi-server DAS's

    % we are at the level of the data.
    % get the type.
    if isfield(eval(structname),'DODS_ML_Type')
      data_type = eval([structname '.DODS_ML_Type']);
    else
      % leave empty
    end

    if exist('MapNames') == 1
      % this option bypasses normal checks for grids and arrays
      % basically, this option is for when there are independent
      % variables within the dataset that can be used as maps.
      names = fieldnames(eval(structname));
      while isempty(strmatch('DODS_ML_Size', names,'exact'))  
	if isfield(eval(structname), newfield1)
	  structname = [structname '.' newfield1];
	  names = fieldnames(eval(structname));
	else
	  break
	end
      end

      % mapnames manually point to elsewhere in the dataset
      % for maps. It does not mean that it is not, also, a
      % grid and not an array.
      gridsize = eval([structname '.DODS_ML_Size']);
      gridsize = gridsize(:)';
      axnames = cellstr(MapNames);

      % force the data type
      data_type = 'Grid';
      ND = size(axnames,1);
      mapinx = cell(ND,1);
      % Note that the
      % number of maps (ND) might no longer match the actual number
      % of dimensions of the SelectableVariable grid.  This requires
      % a new routine to construct the URL constraints -- gridurl
      % assumes that all maps are subsidiary and do not need to be
      % constrained.  The new routine is 'gridgrid'.
    else

      if strcmp(data_type,'Array')
	% ARRAYS COME TO HERE. This code all new on 2004/05/05
	axsizes = eval([structname '.DODS_ML_Size']);
	ND = length(axsizes);
	if exist('axes_order') == 1
	  if max(axes_order) > length(axsizes)
	    % problem with archive-defined axis mappings!
	    dods_err_msg = ['axes_order in ' archive ' does not match' ...
		    ' number of axes in DDS!'];
	    dods_err = 1;
	    return
	  end
	  
	  if axes_order(1) > 0 & isempty(Nlon)
	    Nlon = axsizes(axes_order(1));
	  end
	  if axes_order(2) > 0 & isempty(Nlat)
	    Nlat = axsizes(axes_order(2));
	  end
	  if axes_order(3) > 0 & isempty(Ndepth)
	    Ndepth = axsizes(axes_order(3));
	  end
	  if axes_order(4) > 0 & isempty(Ntime)
	    Ndepth = axsizes(axes_order(4));
	  end
	  geopos = [axes_order zeros(1,4-length(axes_order))];
	  
	  if dods_expert_mode
	    disp([ 'Array index order being forced by axes_order in ' archive])
	  end
	  
	else % axes_order was not defined in archive
	  geopos = zeros(1,4);
	  tmpaxes = zeros(1,4);
	  if ~isempty(Nlon)
	    tmpaxes(1) = Nlon;
	  end
	  if ~isempty(Nlat)
	    tmpaxes(2) = Nlat;
	  end
	  if ~isempty(Ndepth)
	    tmpaxes(3) = Ndepth;
	  end
	  if ~isempty(Ntime)
	    tmpaxes(4) = Ntime;
	  end
	  
	  % first try and sort this out based on size
	  if sum(tmpaxes > 0) == ND & all(diff(sort(axsizes)) ~= 0)
	    if ~isempty(find(tmpaxes(1) == axsizes))
	      geopos(1) = find(tmpaxes(1) == axsizes);
	    end
	    if ~isempty(find(tmpaxes(2) == axsizes))
	      geopos(2) = find(tmpaxes(2) == axsizes);
	    end
	    if ~isempty(find(tmpaxes(3) == axsizes))
	      geopos(3) = find(tmpaxes(3) == axsizes);
	    end
	    if ~isempty(find(tmpaxes(4) == axsizes))
	      geopos(4) = find(tmpaxes(4) == axsizes);
	    end
	  else
	    % now issue a warning to the user that the axes order is assumed
	    str = sprintf('%s', ...
			  'There are no map vectors. ASSUMING axis mappings ',...
			  'and URL constraints based on the ranges (e.g., ',...
			  ['LonRange) given in the file ' archive '.m. Please '],...
			  '*doublecheck* these ranges and reload this ',...
			  'file from the property editor if necessary.  ',...
			  'Values in that file will override anything assumed',...
			  ' here.');
	    dodsmsg(str)
	    % size differentiation doesn't work, go through a few default states
	    if ND == 1 & (tmpaxes(4) > 0)
	      geopos = [0 0 0 1];
	    elseif ND == 2 & all(tmpaxes([1 2]) > 0)
	      geopos = [2 1 0 0];
	    elseif ND == 3 & all(tmpaxes([1 2 3]) > 0)
	      geopos = [2 1 3 0];
	    elseif ND == 4 & all(tmpaxes > 0)
	      % assume lat, lon, depth, time
	      geopos = [2 1 3 4];
	    else
	      
	      % we have absolutely no information about the axes.
	      if ND == 1
		geopos = [0 0 0 1];
		Ntime = axsizes(1);
	      elseif ND == 2
		geopos = [2 1 0 0];
		Nlat = axsizes(1);
		Nlon = axsizes(2);
	      elseif ND == 3
		geopos = [2 1 3 0];
		Nlat = axsizes(1);
		Nlon = axsizes(2);
		Ntime = axsizes(3);
	      elseif ND == 4
		% assume lat, lon, depth, time
		geopos = [2 1 3 4];
		Nlat = axsizes(1);
		Nlon = axsizes(2);
		Ntime = axsizes(3);
		Ndepth = axsizes(4);
	      end
	      
	    end
	    
	  end
	end
      elseif strcmp(data_type,'Grid')
      	% THIS IS A GRID :-) :-) we like grids.
	% get the names of the maps
	names = fieldnames(eval(structname));
	
	% save only those names that are maps for field1
	% they will always occur immediately AFTER field1
	% itself, and will be the last fields in the structure.
	start = strmatch(newfield1, names, 'exact')+1;
	sz = size(names,1);
	axnames = names(start:sz,:);
	
	% set the dimension of map constraints
	ND = size(axnames,1);
      else
	% not a grid, not an array, and no mapnames!
	% exit and tell the user.
	dods_err = 1;
	dods_err_msg = ['Unable to determine maps for this dataset.',...
			'  Please check the DAS and DDS manually.'];
	return
      end % end of data_type check

    end

    % BOTH ARRAYS *AND* GRIDS EXECUTE THIS PART -----------------
    % axindex will hold the indices for each axis, ax will
    % hold the value, and stride will hold the stride.
    axunits = cell(ND,1);
    axindex = cell(ND,1);
    ax = cell(ND, 1);
    stride = ones(ND, 1);
  
    if strcmp(data_type,'Grid')
      % get names and values of maps for grids.  Maps
      % for arrays will be automatically generated below.
      getgridmaps
    end

    % A return statement from getgridmaps does not return us
    % to caller program, even though it is not a separate function
    % but only a script!  execute return here.
    if dods_err
      % make it clear to GUI that URLinfo was not completed!
      URLinfo = [];
      return
    end


  case 'use_old' % USE CACHED METADATA.
    % first pull out overrides from cache, being
    % careful to allow archive.m values to be preserved
    % if such exist.
    data_type = URLinfo.data_type;

    if ~isempty(URLinfo.Nlon)
      Nlon = URLinfo.Nlon;
    end   
    if ~isempty(URLinfo.Nlat)
      Nlat = URLinfo.Nlat;
    end   
    if ~isempty(URLinfo.Ntime)
      Ntime = URLinfo.Ntime;
    end   
    if ~isempty(URLinfo.Ndepth)
      Ndepth = URLinfo.Ndepth;
    end   
    
    if ~isempty(URLinfo.gridsize)
      gridsize = URLinfo.gridsize;
    end
    axnames = URLinfo.axnames;
    ax = URLinfo.axes;
    geopos = URLinfo.geopos;
      
    % determine the number of dimensions
    if ~isempty(URLinfo.axnames)
      % there are maps in these metadata and we must determine
      % their meaning
      ND = size(axnames,1);
    else 
      % no maps were found and the axes order is prescribed
      ND = sum(geopos > 0);
    end
    stride = ones(ND,1);
    axindex = cell(ND,1);

    if strcmp(data_type,'Grid')
      axunits = URLinfo.axunits;
      timebase = URLinfo.timebase;
      start_time = URLinfo.start_time;
      if geopos(1) > 0, xmap = axnames{geopos(1)}; end
      if geopos(2) > 0, ymap = axnames{geopos(2)}; end
      if geopos(3) > 0, zmap = axnames{geopos(3)}; end
      if geopos(4) > 0, tmap = axnames{geopos(4)}; end
  
      % make up the URL that WOULD have gotten us the axis maps, just
      % for the benefit of displaying to the user.  It is not going to
      % be dereferenced because we have cached the DAS.
      Server = deblank(Server(1,:));
      Constraint = '';
      for i = 1:ND
	if ~isempty(Constraint), Constraint = [Constraint, ',']; end
	Constraint = [Constraint field1 '.' axnames{i}];
      end
      if ~isempty(Constraint)
	url = [Server '?' Constraint];
      end
    end
end % end of cache_status switch

% -----------------------------------------------------------------
% This section of code is executed every time gridcat is called.
if ~isempty(Ntime)
  % PCC added the following 2/4/02  BEGIN
  % We can tell the GUI that this data set is just one field that is good
  % for all time by specifying Ntime=1 and a TimeRange pair that is not
  % equal to one another, e.g., TimeRange = [1800 2002].

  if Ntime == 1 & diff(TimeRange) ~= 0
    tmp_times = [];
    if geopos(4) > 0 % There is a time map vector with the data set!
      if length(ax{geopos(4)}) == 1;  
	% If more than one element then problem otherwise OK
	axindex{geopos(4)} = [1 1];
      end
    else
      axindex{geopos(4)} = [];
    end
  else % make time map vector.
    tmp_times = mapvector(TimeRange,1,TimeRange,Ntime);
    ax{geopos(4)} = tmp_times;
    i = find(tmp_times >= ranges(4,1) & tmp_times <= ranges(4,2));
    axindex{geopos(4)} = mminmax(i);
    tmp_times = tmp_times(i);
  end
  % End PCC additions changes here 2/4/02
else

  tmp_times = [];
  if strcmp(data_type,'Grid') & ~isempty(tmap)
    timestring = '';
    if isempty(URLinfo.axnames) % first time around, nothing is cached
      % get time base and time string
      gettimebase
    end % if isempty(URLinfo.axnames)

    % now to determine the START TIME & convert RAW TIME UNITS
    % to DECIMAL DAYS
    if ~isempty(timestring)
      getstarttime
    end % if ~isempty(timestring)
      
    if ~isempty(ax{geopos(4)})
      if isnan(start_time) | isempty(timebase)
	% we are reusing cached information and we were not able to
	% determine a time base before!  Skip the whole thing.
	tmap = [];
	geopos(4) = 0;
	timestring = '';
      else
	% CREATE TMP_T
	tmp_t = ax{geopos(4)};
	minmax_time = mminmax(ax{geopos(4)});
	if (diff(minmax_time) <= 1.001) & (minmax_time(2) < 10) & ...
	      ~strcmp(timebase,'years')
	  % This is a climatology: year < 10AD, time axis less than
	  % a year long and timebase not a year
	  if diff(ranges(4,:)) > 1
	    % if user has selected more than 1 year, give them whole year
	    if exist('MapNames') == 1
	      mapinx{geopos(4)} = ones(size(ax{geopos(4)}));
	      axindex{geopos(4)} = [0 0];
	    else
	      axindex{geopos(4)} = [1 length(tmp_t)];
	    end
	    YEAR = floor(ranges(4,1));
	    while YEAR < ranges(4,2)
	      tmp_times = [tmp_times(:); YEAR+tmp_t(:)];
	      YEAR = YEAR+1;
	    end
	    i = find(tmp_times >= ranges(4,1) & tmp_times <= ...
		ranges(4,2));
	    tmp_times = tmp_times(i);
	  else
	    mapinx{geopos(4)} = zeros(size(ax{geopos(4)}));
	    YEAR = floor(ranges(4,1));
	    while YEAR < ranges(4,2)
	      if exist('MapNames') == 1
		[i] = find(t >= ranges(4,1) & t <= ranges(4,2));
		if ~isempty(i)
		  axindex{geopos(4)} = [0 0];
		  for k = 1:length(i)
		    mapinx{geopos(4)}(i(k)) = 1;
		  end
		end
	      else
		t = [YEAR+tmp_t(:)];
		i = find(t >= ranges(4,1) & t <= ranges(4,2));
		axindex{geopos(4)} = [axindex{geopos(4)}; i];
		tmp_times = [tmp_times(:); t(i)];
	      end
	      YEAR = YEAR+1;
	    end
	      
	    if exist('MapNames') ~= 1
	      i = [axindex{geopos(4)}];
	      if ~isempty(i)
		i = sort(i);  i = i(findnew(i));
		if all(diff(i) == 1)
		  axindex{geopos(4)} = [mminmax(i)];
		else
		  j = find(diff(i) > 1);
		  axindex{geopos(4)} = [i(j+1) max(i); i(1) i(j)];
		end
	      end
	    end
	    
	  end % if diff(ranges(4,:)) > 1
	      
	else

	  % NOT A CLIMATOLOGY
	  if exist('MapNames') == 1
	    [i] = find(tmp_t >= ranges(4,1) & tmp_t <= ranges(4,2));
	    mapinx{geopos(4)} = zeros(size(ax{geopos(4)}));
	    if ~isempty(i)
	      axindex{geopos(4)} = [0 0];
	      for k = 1:length(i)
		mapinx{geopos(4)}(i(k)) = 1;
	      end
	    end
	  else
	    i = find(tmp_t >= ranges(4,1) & tmp_t <= ranges(4,2));
	    axindex{geopos(4)} = mminmax(i);
	    tmp_times = tmp_t(i);
	  end
	end

	% If the time range is empty let the user know that one is
	% needed. Added by PCC 2/8/02
	if isempty(axindex{geopos(4)})
	  str = ['  Warning: No time value in the time range that' ...
		' you selected. Check that the range you selected' ...
		' on the time axis is long enough before you' ... 
		' actually make a data request.'];
	  dodsmsg(str)
	end
      end
    end
  else % if we get here, the dataset not a grid or does not
    % contain a time axis index that we can determine.  Fake it.
    % Give the user 1 point per year.
    YEAR = floor(ranges(4,1));
    i = 1;
    tmp_times = YEAR+0.5;
    while YEAR < ranges(4,2)
      i = i+1;
      YEAR = YEAR+1;
      tmp_times(i) = YEAR+0.5;
    end
    i = find(tmp_times >= ranges(4,1) & tmp_times <= ranges(4,2));
    tmp_times = tmp_times(i);
  end % if is a grid ~isempty(tmap)
end % if Ntime not empty
tmp_times = tmp_times(:);

% CREATE A DEPTH AXIS
if geopos(3) > 0
  if ~isempty(Ndepth)
    disp('Using simulated axis values (depth) to constrain URL')
    depths = mapvector(sort(DepthRange), 1, DepthRange, Ndepth);
    ax{geopos(3)} = depths;
    i = find(depths >= ranges(3,1) & depths <= ranges(3,2));
    axindex{geopos(3)} = mminmax(i);
    depths = depths(i);
  else
    if strcmp(data_type,'Grid') & ~isempty(zmap)
      % Skip if grid but cannot match map with known maps
      depths = ax{geopos(3)};
      if exist('MapNames') == 1
	[i] = find(depths >= ranges(3,1) & depths <= ranges(3,2));
	mapinx{geopos(3)} = zeros(size(depths));
	if ~isempty(i)
	  axindex{geopos(3)} = [0 0];
	  for k = 1:length(i)
	    mapinx{geopos(3)}(i(k)) = 1;
	  end
	end
      else
	i = find(depths >= ranges(3,1) & depths <= ranges(3,2));
	axindex{geopos(3)} = mminmax(i);
	depths = depths(i);
      end
    end
  end

  % If the depth range is empty let the user know that one is
  % needed. Added by PCC 2/8/02
  if isempty(axindex{geopos(3)})
    str = ['  Warning: No depth value in the depth range that' ...
	  ' you selected. Check that the range you selected' ...
	  ' on the depth axis is long enough before you' ... 
	  ' actually make a data request.'];
    dodsmsg(str)
  end
end
depths = depths(:);

% CREATE A LATITUDE AXIS
% PCC changed calculation of constraint for Nlat case on 2/1/02. 
if geopos(2) > 0
  if ~isempty(xystride)
    stride(geopos(2)) = xystride;
  end
  if ~isempty(Nlat)
    disp('Using simulated axis values (Lat) to constrain URL')
    locate_y = mapvector(sort(LatRange),1,LatRange,Nlat);
    ax{geopos(2)} = locate_y;
    axnames{geopos(2)} = 'LatVector';
    [i] = find(locate_y >= ranges(2,1) & locate_y <= ranges(2,2));
    axindex{geopos(2)} = mminmax(i);
    locate_y = locate_y(i);
  else
    if strcmp(data_type,'Grid') & ~isempty(ymap)
      locate_y = ax{geopos(2)};
    
      if exist('MapNames') == 1
	[i] = find(locate_y >= ranges(2,1) & locate_y <= ranges(2,2));
	mapinx{geopos(2)} = zeros(size(locate_y));
	if ~isempty(i)
	  axindex{geopos(2)} = [0 0];
	  for k = 1:length(i)
	    mapinx{geopos(2)}(i) = 1;
	  end
	end
      else
	i = find(locate_y >= ranges(2,1) & locate_y <= ranges(2,2));
	axindex{geopos(2)} = mminmax(i);
	locate_y = locate_y(i);
      end
    end % end of check for is a grid and ymap
  end % end of check for Nlat
  % If the latitude range is empty let the user know that
  % one is needed. Added by PCC 2/8/02
  if isempty(axindex{geopos(2)})
    str = ['  Warning: No latitude value in the latitude range' ...
	  ' that you selected. Check that the range you selected' ...
	  ' on the latitude axis is long enough before you' ...
	  ' actually make a data request.'];
    dodsmsg(str)
  end
end
% END CHANGES HERE
locate_y = locate_y(:)';

% CREATE A LONGITUDE AXIS
% if we've got info from the archive.m file, use it!
% PCC changed calculation of constraint for Nlon case on 2/1/02.
if geopos(1) > 0
  if ~isempty(xystride)
    stride(geopos(1)) = xystride;
  end
  if ~isempty(Nlon)
    disp('Using simulated axis values (Lon) to constrain URL')
    locate_x = mapvector(sort(LonRange),1,LonRange,Nlon);
    ax{geopos(1)} = locate_x;
    axnames{geopos(1)} = 'LonVector';
    [start_lon, end_lon] = splitrequest(mminmax(locate_x), ...
	ranges(1,:));
    if length(start_lon) > 1
      i1 = mminmax(find(locate_x >= start_lon(1) & ...
	  locate_x <= end_lon(1)));
      i2 = mminmax(find(locate_x >= start_lon(2) & locate_x <= ...
	  end_lon(2)));
      axindex{geopos(1)} = [i1; i2];
    else
      axindex{geopos(1)} = mminmax(find(locate_x >= start_lon(1) & ...
	  locate_x <= end_lon(1)));
    end
    [locate_x, xorder] = xrange('xarg', georange, locate_x);
    i = find(locate_x >= ranges(1,1) & locate_x <= ranges(1,2));
    locate_x = locate_x(i);
  else

    if strcmp(data_type,'Grid') & ~isempty(xmap)
      locate_x = ax{geopos(1)};
      % Skip if grid but cannot match map with known maps
      % set the stride
      if ~isempty(xystride)
	stride(geopos(1)) = xystride;
      end
      [start_lon, end_lon, dods_err, dods_err_msg] = ...
	  splitrequest(mminmax(locate_x), ranges(1,:));
      if dods_err
	% make it clear to GUI that URLinfo was not completed!
	URLinfo = [];
	return
      end

      % set the x-axis indices
      if exist('MapNames') == 1
	mapinx{geopos(1)} = zeros(size(locate_x));
	if length(start_lon) > 1
	  [i1] = find(locate_x >= start_lon(1) & locate_x <= end_lon(1));
	  [i2] = find(locate_x >= start_lon(2) & locate_x <= end_lon(2));
	  if ~isempty(i1) | ~isempty(i2)
	    axindex{geopos(1)} = [0 0];
	    i = [i1(:); i2(:)];
	    for k = 1:length(i)
	      mapinx{geopos(1)}(i(k)) = 1;
	    end
	  end
	elseif length(start_lon) == 1
	  [i] = find(locate_x >= start_lon(1) & locate_x <= end_lon(1));
	  if ~isempty(i)
	    axindex{geopos(1)} = [0 0];
	    for k = 1:length(i)
	      mapinx{geopos(1)}(i(k)) = 1;
	    end
	  end
	end
      else
	if length(start_lon) > 1
	  i1 = mminmax(find(locate_x >= start_lon(1) & ...
	      locate_x <= end_lon(1)));
	  i2 = mminmax(find(locate_x >= start_lon(2) & locate_x <= ...
	      end_lon(2)));
	  axindex{geopos(1)} = [i1; i2];
	else
	  axindex{geopos(1)} = mminmax(find(locate_x >= start_lon(1) & ...
	      locate_x <= end_lon(1)));
	end
	[locate_x, xorder] = xrange('xarg', georange, locate_x);
	i = find(locate_x >= ranges(1,1) & locate_x <= ranges(1,2));
	locate_x = locate_x(i);
      end
    end % if is a grid and xmap
  end % if Nlon not empty

  % If the longitude range is empty let the user know that one is
  % needed. Added by PCC 2/8/02
  if isempty(axindex{geopos(1)})
    str = ['  Warning: No longitude value in the longitude range' ...
	  ' that you selected. Check that the range you selected' ...
	  ' on the longitude  axis is long enough before you' ...
	  ' actually make a data request.'];
    dodsmsg(str)
  end
end
% END CHANGES HERE
locate_x = locate_x(:);

if exist('MapNames') == 1
  % SET UP AXIS CONSTRAINTS FOR INDEPENDENT GRIDS
  % reset the stride
  % this next bit takes care of the fact that some maps
  % may be just vectors, others MxNxP ... arrays.
  M = gridsize;
  stride = ones(ND+1,1);
  axindex = cell(ND+1,1);
  inx = ones(M);
  for i = 1:ND
    s = size(ax{i});
    if sum(s > 1) == 1 & any(max(s) == M)
      % axis is a vector for an N-Dim array
      % find which dimension
      j = find(max(s) == M);
      k = find(~mapinx{i}(:));
      str = 'inx(';
      for l = 1:length(M)
	if l == j
	  str = [str 'k,'];
	else
	  str = [str ':,'];
	end
      end
      str = str(1:length(str)-1);
      str = [str ') = 0;'];
      eval(str)
    elseif sum(s > 1) > 1
      % axis is some kind of array.  Only consider if it
      % is EXACTLY the size of M.
      if length(s) == length(M)
	if all(s == M)
	  inx = inx.*mapinx{i};
	else
	  % one of map is N-dim array, but not size M!
	  % abort
	  dods_err = 1;
	  dods_err_msg = sprintf('%s%s%s%s','Grid ', axnames{i}, ...
	      'does not match size of variable ', data_name{1});
	  return
	end
      else
	% some map is array and has different dimensions
	%  than M.  abort
	dods_err = 1;
	dods_err_msg = sprintf('%s%s%s%s','Grid ', axnames{i}, ...
	    'has different number of dimensions than ', ...
	    data_name{1});
	return;
      end
    else
      % sum(s > 1) == 1 but max(s) ~= any of M
      % abort
      dods_err = 1;
      dods_err_msg = sprintf('%s%s%s%s','Grid ', axnames{i}, ...
	  'is not the correct length to be a map for ', ...
	  data_name{1});
	return;
    end
  end
  locate_x = []; locate_y = []; tmp_times = []; depths = [];
  i = find(inx);
  % at this point we should be able to GUARANTEE that each
  % axis is either a properly sized vector, or a matrix of
  % the same size as the grid.
  
  % make placeholders
  axindex{1} = [zeros(length(M),2)];
  for l = 1:ND
    s = size(ax{l});
    if sum(s > 1) == 1 & any(max(s) == M)
      axindex{l+1} = [0 0];
    elseif sum(s > 1) > 1
      axindex{l+1} = [zeros(length(M),2)];
    end
  end
  
  if ~isempty(i)
    % now time to make the actual axis constraints!
    k = cell(1,length(M));
    [k{:}] = ind2sub(M,i);
    k = cat(2,k{:});
    c1 = min(k); c2 = max(k);
    axindex{1} = [c1(:), c2(:)];
    for l = 1:ND
      s = size(ax{l});
      if sum(s > 1) == 1 & any(max(s) == M)
	% axis is a vector for an N-Dim array
	% find which dimension
	j = find(max(s) == M);
	axindex{l+1} = [min(k(:,j)), max(k(:,j))];
      elseif sum(s > 1) > 1
	% axis an array
	c1 = min(k); c2 = max(k);
	axindex{l+1} = [c1(:), c2(:)];
      end
    end
    
    if geopos(1) > 0 & geopos(2) > 0
      s1 = size(ax{geopos(1)});
      s2 = size(ax{geopos(2)});
      if sum(s1 > 1) == 1 & sum(s2 > 1) == 1
	j = find(max(s1) == M);
	x = ax{geopos(1)};
	locate_x = x(k(:,j));
	j = find(max(s2) == M);
	y = ax{geopos(2)};
	locate_y = y(k(:,j));
      elseif sum(s1 > 1) > 1 & sum(s2 > 1) > 1
	locate_x = ax{geopos(1)}(i);
	locate_y = ax{geopos(2)}(i);
      elseif sum(s1 > 1) == 1 & sum(s2 > 1) > 1
	x = zeros(M);
	x = x(:);
	l = max(s1); m = length(x)/l;
	for k = 1:m
	  x((k-1)*l+(1:l)) = ax{geopos(1)};
	end
	x = reshape(x,M);
	locate_x = ax{geopos(1)}(i);
	locate_y = ax{geopos(2)}(i);
      elseif sum(s1 > 1) > 1 & sum(s2 > 1) == 1
	y = zeros(M);
	y = y(:);
	l = max(s2); m = length(y)/l;
	for k = 1:m
	  y((k-1)*l+(1:l)) = ax{geopos(2)};
	end
	y = reshape(y,M);
	locate_x = ax{geopos(1)}(i);
	locate_y = ax{geopos(2)}(i);
      end
    end
    if geopos(3) > 0
      s = size(ax{geopos(3)});
      if sum(s > 1) == 1
	j = find(max(s) == M);
	d = ax{geopos(3)};
	depths = d(k(:,j));
      else
	depths = ax{geopos(3)}(i);
      end
    end
    if geopos(4) > 0
      s = size(ax{geopos(4)});
      if sum(s > 1) == 1
	j = find(max(s) == M);
	t = ax{geopos(3)};
	tmp_times = t(k(:,j));
      else
	tmp_times = ax{geopos(4)}(i);
      end
    end
  end % if ~isempty(i)
else
  % using dependent maps.  Much simpler case.
  % make a square
  y = locate_y;
  x = locate_x;
  locate_y = [min(y) mminmax(y) max(y) min(y)];
  locate_x = [mminmax(x) max(x) min(x) min(x)];
end

% change from 1:N -type indices to 0:N-1.
for i = 1:size(axindex,1)
  if ~isempty(axindex{i})
    for j = 1:size(axindex{i},1);
      axindex{i}(j,:) = axindex{i}(j,:) - 1;
    end
  end
end

switch cache_status
  case 'get_new'
    % first strip out any 'global' fields from data_*, since global
    % fields are not going to be variables in the DDS.
    j = find(~strncmp('global', lower(data_name), 6));
    data_name = data_name(j);
    data_scale = data_scale(j);
    data_null = data_null(j);
    data_units = data_units(j);
    data_server = data_server(j);
    
    j = find(~strncmp(lower('DODS_ML'), lower(data_name), 6));
    data_name = data_name(j);
    data_scale = data_scale(j);
    data_null = data_null(j);
    data_units = data_units(j);
    data_server = data_server(j);
    
    % this will ALWAYS be true for an array (no maps) will it not?
    URLinfo.axnames = axnames;
    URLinfo.axes = ax;
    URLinfo.geopos = geopos;
    URLinfo.axunits = axunits;
    URLinfo.timebase = timebase;
    URLinfo.start_time = start_time;
    URLinfo.data_name = data_name;
    URLinfo.data_scale = data_scale;
    URLinfo.data_null = data_null;
    URLinfo.data_units = data_units;
    URLinfo.data_server = data_server;
    URLinfo.data_type = data_type;
    URLinfo.gridsize = gridsize;
    % cache any faked axis info.
    URLinfo.Nlon = Nlon;
    URLinfo.Nlat = Nlat;
    URLinfo.Ndepth = Ndepth;
    URLinfo.Ntime = Ntime;
end

% these fields may change each time the dataset is accessed.
URLinfo.axindex = axindex;
URLinfo.stride = stride;

warn = 0;
for i = 1:ND
  if isempty(axindex{i}) & ~any(geopos) == i
    warn = 1;
  end
end

if warn
  str = sprintf('%s\n', ...
      'Warning: some axes are not able to be automatically constrained', ...
      'by the GUI.  You will be prompted to constrain them if/when an', ...
      'actual data download is requested.'); 
  dodsmsg(str)
end
return
