function [URLs, URLinfo] = gridgrid(mode, archive, URLinfo, variables, server, urllist)

URLs = '';
pos = URLinfo.geopos;
axnames = URLinfo.axnames;
ND = length(axnames);
axindex = URLinfo.axindex;
gridindex = axindex{1};
if any(gridindex == -1)
  gridindex = nan*ones(size(gridindex));
end
axindex = axindex(2:ND+1);
stride = URLinfo.stride;
gridstride = stride(1);
stride = stride(2:ND+1);
ax = URLinfo.axes;

% Get constraints on dimensions that are not of interest in variable from
% archive.m
if exist(archive) ~= 2 
  dodsmsg(['Problem reading dataset metadata ' get_archive '.m'])
  return
else
  eval(archive)
end

switch mode
  case 'get'
    
    makeconstraints = 0;
    % user is actually trying to download data.
    % deal with any unconstrained axes by ABORTING
    % until we have time to implement this properly.
    for j = 1:ND
      if isempty(axindex{j}) | any(axindex{j} == -1)
	dodsmsg('Some axes were not properly constrained')
	return
%	lonstr = 'Longitude: '; 
%	latstr = 'Latitude: ';
%	depstr = 'Depth: ';
%	timestr = 'Time: ';
%	str = cell(4,1);
%	[str{:}] = deal('');
%	if pos(1) > 0
%	  str{1} = [lonstr, axnames{pos(1)}];
%	end
%	if pos(2) > 0
%	  str{2} = [latstr, axnames{pos(2)}];
%	end
%	if pos(3) > 0
%	  str{3} = [depstr, axnames{pos(3)}];
%	end
%	if pos(4) > 0
%	  str{4} = [timestr, axnames{pos(4)}];
%	end
%	str = strvcat(str{:});
%	str2 = '';
%	for i = 1:size(str,1)
%	  str2 = [str2, sprintf('%s\n', deblank(str(i,:)))];
%	end
%	str = str2;
%	
%	prompt = '';
%	l = length(size(ax{j})); s = size(ax{j});
%	for i = 1:l
%	  if s(i) > 1
%	    prompt = [ prompt '1:1:', num2str(s(i)) '  '];
%	  end
%	end
%	l = sum(s > 1);
%	str = sprintf('%s\n', ...
%	    'IDENTIFIED AXES', ...
%	    str', ...
%	    ' ', ...
%	    [ 'UNIDENTIFIED AXIS: ', axnames{j}], ...
%	    [ 'SIZE: ', num2str(size(ax{j}))], ...
%	    [ 'RANGE: ', num2str(mminmax(ax{j}))], ...
%	    ' ', ...
%	    'Either the identity of this axis or its units', ...
%	    'were not able to be identified by the GUI.', ...
%	    'Please select a slice such as', ...
%	    ' ', ...
%	    [ '                ', prompt], ...
%	    ' ', ...
%	    'for the data download.');
%	slice = dodsdlg(str, ...
%	    'NVODS Browser: Select Slice', 1, {prompt}, zeros(3,3));
%	if ~isempty(slice)
%	  slice = char(slice);
%	else
%	  % don't warn here as getrectg/browse will do the warning
%	  return
%	end
%	k = findstr(slice,':');
%	if length(k) ~= 2*l
%	  dodsmsg('Not able to parse the selected slice.');
%	  return
%	end
%	% must clean this up!	
%	for i = 1:l
%	  if i == 1
%	    i1 = str2num(slice(1:k(1)-1));
%	  elseif i == l
%	    i2 = str2num(slice(k(2)+1:length(slice)));
%	  else
%	  end
%	end
%	s = str2num(slice(k(1)+1:k(2)-1));
%	if isempty(i1) | isempty(i2) | isempty(s)
%	  dodsmsg('Not able to parse the selected slice.');
%	  return
%	end
%	axindex{j} = [i1-1 i2-1];
%	stride(j) = s;
%	URLinfo.stride = stride;
%	URLinfo.axindex = axindex;
%	makeconstraints = 1;
      end
    end
  case 'cat'
    % we have no constraints yet: fabricate some
    makeconstraints = 1;
end

if ~makeconstraints
  URLs = urllist;
  return
end

% get the number of iterations necessary for each axis
for k = 1:ND
  if isempty(axindex{k})
    % put in a fake, placeholding constraint for the 
    % purpose of giving the user completely constrained
    % URLs.  These constraints will be redetermined at 
    % getdata time.
    axindex{k} = [NaN NaN];
  elseif any(axindex{k} == -1)
    axindex{k} = nan*ones(size(axindex{k}));
  end
end

gridconstraint = axnames;
% loop through possible axes.  Stride variable should now
% be set correctly in gridcat.  -- dbyrne, 2002/09/19
for k = 1:ND
  stridestr = num2str(stride(k));
  % now make the constraints for this axis.
  for it = 1:size(axindex{k},1)
    gridconstraint{k} = [gridconstraint{k}, ...
	['[' num2str(axindex{k}(it,1)) ':' ...
	  stridestr ':' num2str(axindex{k}(it,2)) ']']];
  end
end

varconstraint = cellstr(variables);
for k = 1:size(variables,1)
  stridestr = num2str(gridstride);
  for it = 1:size(gridindex,1)
  varconstraint{k} = [varconstraint{k}, ...
	['[' num2str(gridindex(it,1)) ':' ...
	  stridestr ':' num2str(gridindex(it,2)) ']']];	
  end
end
numurls = 1;
      
sz = size(server,1);
if sz > 1
  URLs = cell(sz,1);
  for j = 1:sz
    Constraint = '';
    Constraint = [Constraint varconstraint{j}];
    for i = 1:size(axnames,1)
      if ~isempty(Constraint), Constraint = [Constraint ',']; end
      Constraint = [Constraint gridconstraint{i}];
    end
    URLs{j} = [deblank(server(j,:)), '?' Constraint];
  end
  URLs = strvcat(URLs);
elseif sz == 1
  URLs = '';
  Constraint = '';
  % now loop through variables and add gridconstraint to each
  for i = 1:size(variables,1)
    if i > 1, Constraint = [Constraint ',']; end
    Constraint = [Constraint varconstraint{i}];
  end
  for i = 1:size(axnames,1)
    if ~isempty(Constraint), Constraint = [Constraint ',']; end
    Constraint = [Constraint gridconstraint{i}];
  end
  % now add the constraint onto the end of the base URL
  URLs = [URLs, deblank(server) '?' Constraint];
elseif sz == 0
  % we've got base urls from a CS.
  URLs = cellstr(urllist);
  % now loop through variables and add gridconstraint to each
  for i = 1:size(variables,1)
    if i > 1, Constraint = [Constraint ',']; end
    Constraint = [Constraint varconstraint{i}];
  end
  for i = 1:size(axnames,1)
    if ~isempty(Constraint), Constraint = [Constraint ',']; end
    Constraint = [Constraint gridconstraint{i}];
  end
  for j = 1:size(urllist,1)
    URLs{j} = [URLs{j} '?' Constraint];
  end
  URLs = strvcat(URLs);
end

URLinfo.urlconstraint = [];

return
