%               REYNOLDS MASK

% The preceding empty line is important.
%
% Reynolds data at NOAA in Boulder.
% Also note that users will need DODS-2.15 or greater on the client 
% side to read the data.

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg'; 
Server = 'http://www.cdc.noaa.gov/cgi-bin/nph-nc/Datasets/reynolds_sst/lsmask.nc';

Ntime = 1;

% VARIABLES -- REQUIRED
LonRange = [0.0 360.0];
LatRange = [90.0 -90.0];
TimeRange = [1800 str2num(datestr(date,10))];
DepthRange = [0 0];
DepthUnits = '';
Resolution = 111.0;

DataName = 'Land Mask for Reynolds Blended SST fields  - NCEP';   

Acknowledge = sprintf('%s\n%s', ...
    [ 'The authors of this dataset are R.W. Reynolds and T. M. Smith.  ', ...
      'The data were provided by the NOAA-CIRES Climate Diagnostics Center ', ...
      '(http://www.cdc.noaa.gov) and accessed via ', ...
      'the National Virtual Ocean Data System (NVODS: ', ...
      'http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citation: Reynolds, R. W. and T. M. Smith (1995).  A ', ...
      'high-resolution global sea surface temperature climatology.  ', ...
      'Journal of Climate 8, 1571--1583. ']);

SelectableVariables = str2mat('Land_Mask');
DodsName = 'lsmask';

DataNull = [NaN NaN NaN NaN -1];

% COMMENTS
Comments = sprintf('%s\n', ...
'                               Reynolds Land Mask', ...
'   ', ...
'    This is the land mask for the optimally-interpolated SST analysese of Reynolds ', ...
'    and Smith (1995). The OI or "blended analyses" data sets to which this mask ', ...
'    applies that are served via NVODS are: ', ...
'        the monthly cLimatological fields from URI,', ...
'        the daily climatological fields from CDC,', ...
'        the monthly mean fields for 198-present from CDC,', ...
'        the weekly fields for 1982-1990 from CDC, and the ', ...
'        the weekly fields for 1990-present from CDC.', ...
' ', ...
'    The mask has +1 for ocean and nan for land so that it can be multiplied times',...
'    Sea_Temp from any of the other Reynold products here to mask out land. The',...
'    command would look like: sst = Rxx_Land_Mask .* Ryy_Sea_Temp; IF the two data',...
'    requests are for EXACTLY the same area. To plot the result in a new window:',...
'        figure;imagesc(Rxx_Longitude,Rxx_Latitude,sst);set(gca,''ydir'',''normal'')',...
'    where xx is the request number for the land mask and yy is the request number', ...
'    for the sea surface temperature.');
