function [out1, out2] = dispmenu(argin1, argin2, argin3, argin4, argin5)
%
% DISPMENU      Part of the NVODS data browser.
%
%            Deirdre Byrne, U Maine, 2000/01/07
%                 dbyrne@umeoce.maine.edu

%           Modified by Xin Zhang, U. of Rhode Island, 2002/09
%                zhangxin@ele.uri.edu

% local variables
global display_menu display_count display_fig display_index
global display_choices all_display_data all_display_metadata
global combo_display_name

% notes: display_choices: one entry per plot number
% all_display_data: one entry per Rxx
% all_display_metadata: one entry per dataset queried
% acqno: Rxx number
% whichplot, plotno: plot%i

if isstr(argin1)
  switch argin1
    case 'addplot'
      sz = size(display_choices,1);
      whichplot = sz+1;
      Rxxno = get(display_menu{2},'value');
      if Rxxno == 0
	Rxxno = 1;
      end
      str = get(display_menu{2},'string');
      str = deblank(str(Rxxno,:));
      % string begins with 'R' and ends with '_'
      % strip these out.
      str = str(2:length(str)-1);
      acqno = str2num(str);
      display_choices = [display_choices(:); ...
	struct('all_flag', 0, 'click', 0, 'acqno', acqno, ... 
        'acqno_array', [0 0 0 0], ...
        'xyzzz', [0 0 0 0], 'x', 1, 'x_slice', '', 'x_slicesize', '', ...
	    'y', 1, 'y_slice', '', 'y_slicesize', '', ...
	    'z', 1, 'z_slice', '', 'z_slicesize', '', ...
	    'zz', 1, 'zz_slice', '', 'zz_slicesize', '', ...
	    'figure', 'figure', 'plot_type', 'imagesc', ...
	    'clim', [], ...
	    'cval', [], ...
	    'linestyle', '-', ...
	    'color', 'k','scale',1, 'marker', '.', ...
	    'shading', 'flat')]; 
      plotinit('initial', whichplot);
    
      for varnum = 5:8
	callbackstring = sprintf('%s%i%s%i%s%i%s%i%s', ...
	    '[browse_var, browse_slice] =  dispmenu(''getslice'',', ...
	    varnum, ...
	    [ '); if ~isempty(browse_slice), ', ...
		'if exist(browse_var) == 1, browse_dims = nan; ', ...
		'eval(browse_slice, ''% put error message here'');', ...
		'dispmenu(''setslicesize'',' ], ...
	      varnum, ...
	    [ ', browse_dims), else, dispmenu(''setslicesize'',' ], ...
	      varnum, ...
	  [ ', 0); end; else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; clear browse_slice browse_var browse_dims']);
        evalin('base',callbackstring)
      end
      % refresh string for first listbox
      str = get(display_menu{1},'string');
      str = strvcat(str, sprintf('plot%i', whichplot));
      set(display_menu{1}, 'string', str, 'value', whichplot);
      
      set(cat(2, display_menu{[1:16 20]}), 'enable', 'on')   % Modified by Xin
      set(display_menu{9}(4), 'enable', 'off')
      % calling case 1 will set slice sizes and so on
      dispmenu(1)

    case 'applytoall'
     % set everything except Rxx_ value
     whichplot = get(display_menu{1},'value');
     numplots = size(display_choices,1);

     % catch plot type change first
     if isstr(argin2)
       % do some things
       fig = display_choices(whichplot).figure;
       plot_type = display_choices(whichplot).plot_type;
       color = display_choices(whichplot).color;
       linestyle = display_choices(whichplot).linestyle;
       scale = display_choices(whichplot).scale;
       marker = display_choices(whichplot).marker;
       shading = display_choices(whichplot).shading;
       clim = display_choices(whichplot).clim;
       cval = display_choices(whichplot).cval;
       % reset all plot type options to these
       [display_choices(:).figure] = deal(fig);
       [display_choices(:).plot_type] = deal(plot_type);
       [display_choices(:).color] = deal(color);
       [display_choices(:).linestyle] = deal(linestyle);
       [display_choices(:).marker] = deal(marker);
       [display_choices(:).shading] = deal(shading);
       [display_choices(:).clim] = deal(clim);
       [display_choices(:).cval] = deal(cval);
       return
     end
      
     varnum = argin2;
     switch varnum
      case 5
       whichvar = display_choices(whichplot).x;
       slice = display_choices(whichplot).x_slice;
       slicesize = display_choices(whichplot).x_slicesize;
       
      case 6
       whichvar = display_choices(whichplot).y;
       slice = display_choices(whichplot).y_slice;
       slicesize = display_choices(whichplot).y_slicesize;
       
      case 7
       whichvar = display_choices(whichplot).z;
       slice = display_choices(whichplot).z_slice;
       slicesize = display_choices(whichplot).z_slicesize;
	
      case 8
       whichvar = display_choices(whichplot).zz;
       slice = display_choices(whichplot).zz_slice;
       slicesize = display_choices(whichplot).zz_slicesize;
     end
      
     acqno = display_choices(whichplot).acqno;
     acqchoices = cat(1,all_display_data(:).acqno);
     acqindex = find(acqchoices == acqno);
     varname = deblank(all_display_data(acqindex).name(whichvar,:));
     if instr(varname, slice)
       l = min(findstr(varname,'_'));
       rootname = varname(l+1:length(varname));
       if strcmp(varname, slice)
	 sliceprefix = '';
	 slicesuffix = '';
       else
	 k = instr(varname, slice);
	 l = size(varname, 2);
	 sliceprefix = slice(1:k-1);
	 slicesuffix = slice(k+l:length(slice));
       end

       cantapply = [];
       for i = 1:numplots
	 acqno = display_choices(i).acqno;
	 acqchoices = cat(1,all_display_data(:).acqno);
	 acqindex = find(acqchoices == acqno);
	 name = deblank(all_display_data(acqindex).name(whichvar,:));
	 if instr(rootname, name)
	   % first check the same position on the variable list
	   switch varnum
	    case 5
	     display_choices(i).x = whichvar;
	     display_choices(i).x_slice = [sliceprefix name ...
		    slicesuffix];
	     
	    case 6
	     display_choices(i).y = whichvar;
	     display_choices(i).y_slice = [sliceprefix name ...
		    slicesuffix];
		
	    case 7
	     display_choices(i).z = whichvar;
	     display_choices(i).z_slice = [sliceprefix name ...
		    slicesuffix];
		
	    case 8
	     display_choices(i).zz = whichvar;
	     display_choices(i).zz_slice = [sliceprefix name ...
		    slicesuffix];
	   end
	    
	   % get new slicesize
	   callbackstring = sprintf('%s%i%s%i%s%i%s%i%s', ...
	       '[browse_var, browse_slice] =  dispmenu(''getslice'',', ...
	       varnum, ...
	       [ '); if ~isempty(browse_slice), ', ...
		 'if exist(browse_var) == 1, browse_dims = nan; ', ...
		 'eval(browse_slice, ''% put error message here'');', ...
		 'dispmenu(''setslicesize'',' ], ...
      	       varnum, ...
	       [ ', browse_dims), else, dispmenu(''setslicesize'',' ], ...
               varnum, ...
	       [ ', 0); end; else, dispmenu(''setslicesize'',' ], ...
	       varnum, ...
	       [ ', 0); end; clear browse_slice browse_var browse_dims']);
	   evalin('base',callbackstring)
	    
	 else
	   % root name is not in thse string	   
	   % if no match there, check all variables
	   for j = 1:size(all_display_data(acqindex).name,1)
	     wv = 0;
	     if instr(rootname, name)
	       wv = i;
	       break
	     end
	   end
	   if wv > 0
	     display_choices(i).x = wv;
	     display_choices(i).x_slice = [sliceprefix name ...
		    slicesuffix];
	     % set new sizes of full and slice
	     dims = all_display_data(acqindex).size{whichvar};
	     fullstr = 'Full Downloaded size: ';
	     for i = 1:length(dims)
	       fullstr = [fullstr, sprintf('%i ', dims(i))];
	     end
	     set(display_menu{varnum}(3),'string', fullstr);
	     
	     callbackstring = sprintf('%s%i%s%i%s%i%s%i%s', ...
		  '[browse_var, browse_slice] =  dispmenu(''getslice'',', ...
		  varnum, ...
		  [ '); if ~isempty(browse_slice), ', ...
		      'if exist(browse_var) == 1, browse_dims = nan; ', ...
		      'eval(browse_slice, ''% put error message here'');', ...
		      'dispmenu(''setslicesize'',' ], ...
		    varnum, ...
		  [ ', browse_dims), else, dispmenu(''setslicesize'',' ], ...
		    varnum, ...
		[ ', 0); end; else, dispmenu(''setslicesize'',' ], ...
		  varnum, ...
		[ ', 0); end; clear browse_slice browse_var browse_dims']);
	     evalin('base',callbackstring)
	   else
	     cantapply = [cantapply i];
	   end
	 end
       end % end of loop through plots
	
       if ~isempty(cantapply)
	 str = sprintf('plot%i ', cantapply);
	 str = sprintf('Change cannot be applied to plot(s) %s', str);
	 dodsmsg(str)
       end
     else
       % variable name does not appear in slice
       % this is not allowed
     end
      
    case 'changecolor'
	if isempty(findfig('NVODS display'))
	  return
	end
	colors = argin2;
	k = findobj(display_fig,'type','uicontrol');
	set(k,'foregroundcolor',colors(1,:), ...
	    'backgroundcolor',colors(2,:))
	% all of the edit box handles
	h = cat(1,display_menu{5:8});
	h = h(:,5);
	h = h(:)';
	h = [h display_menu{4}];
	h = [h display_menu{15}(1)]; 
	set(h,'backgroundcolor', colors(3,:))
	return
      
    case 'delall'
      display_choices = display_choices([]);
      set(display_menu{1},'string', '', 'value', 0)
      set(cat(2, display_menu{[1:16 21]}), 'enable', 'off')   % Modified by Xin Zhang
      set(display_menu{9}(1), 'enable', 'on')
    
    case 'delplot'
      whichplot = get(display_menu{1},'value');
      if all(size(display_choices) > 0)
	sz = size(display_choices,1);
	if whichplot == 1;
	  display_choices = display_choices(2:sz);
	elseif whichplot < sz
	  display_choices = display_choices([1:whichplot-1 whichplot+1:sz]);
	else
	  display_choices = display_choices([1:sz-1]);
	end
	% refresh string and display for first listbox
	sz = sz - 1;
	whichplot = whichplot - 1;
	if whichplot < 1, whichplot = 1; end
	str = '';
	for i = 1:sz
	  str = strvcat(str, sprintf('plot%i', i));
	end
	if sz > 0
	  set(display_menu{1}, 'string', str, 'value', whichplot);
	  % calling case 1 will set all the buttons to a reasonable value
	  dispmenu(1)
	else
	  display_choices = display_choices([]);
	  set(display_menu{1},'string', '')
	  set(cat(2, display_menu{[1:16 20]}), 'enable', 'off')   %Modified by Xin
	  set(display_menu{9}(1), 'enable', 'on')
	end
      end
    
   case 'display'
    % this called from unpack.m, and from the browser.
    if nargin == 1
      if isempty(findfig('NVODS display'))
	% open a new display figure if needed!
	fontsize = 0;
	figsize = [0 0 0 0];
	colors = zeros(3,3);
	% generate a new figure
	dispmenu('start', fontsize, figsize, colors)
	
	% now reset the plotchoices with some defaults
	display_acq_urls = size(all_display_data,1);
	if display_acq_urls > 0;
	  
	  set(cat(2, display_menu{[1:16 20]}), 'enable', 'on')  % Modified by Xin
	  set(display_menu{9}(3), 'label','Set Z-data')
	  set(display_menu{9}(4), 'enable', 'off')
	  
	  [display_choices(1:display_acq_urls)] = ...
	      deal(struct('all_flag', 0, 'click', 0, 'acqno', 1, ...
           'acqno_array', [0 0 0 0], ...
           'xyzzz', [0 0 0 0], 'x', 1, 'x_slice', '', 'x_slicesize', '', ...
           'y', 1, 'y_slice', '', 'y_slicesize', '', ...
	   'z', 1, 'z_slice', '', 'z_slicesize', '', ...
	   'zz', 1, 'zz_slice', '', 'zz_slicesize', '', ...
	   'figure', 'figure', ...
	   'plot_type', 'imagesc', 'clim', [], ...
	   'cval', [], ...
	   'linestyle', '-', 'color', 'k', 'scale',1,...
	   'marker', 'none', 'shading', ...
	   'flat'));
	  display_choices = display_choices(:);
	
	  str1 = '';
	  str2 = '';
	  
	  for i = 1:display_acq_urls
	    % note: the acquisition number is the one piece
	    % of information that links the display_choice
	    % to the all_display_data matrix.
	    acqno = all_display_data(i).acqno;
	    whichplot = i;
	    display_choices(whichplot).acqno = acqno;
	    
	    str = sprintf('plot%i', whichplot);
	    str1 = strvcat(str1, str);
	    set(display_menu{1}, 'string', str1, 'value', whichplot);
	    
	    str = sprintf('R%i_', acqno);
	    str2 = strvcat(str2, str);
	    % calling dispmenu case 1 will set all the buttons to
	    % reasonable values.
	    % now try to guess the most reasonable type
	    % of plot for these data.  Plotinit does NOT set
	    % the desired slice.
	    plotinit('initial', whichplot);
	    % this will *also* call plotinit, but should preserve
	    % the auto-selected plot type and set the slice correctly
	    dispmenu(1)
	  end  % end of for-loop
	  % add in the 'All' selection to Rxx choices
	  str2 = strvcat(str2, 'All');
	  % set the value at the most recently acquired URL
	  set(display_menu{2},'string',str2,'value', ...
			    size(str2,1)-1);

	  % enable the figure to be accessed from browse window
	  browse('enabledisplay')
	  % reveal the figure
	  set(display_fig,'visible','on')
	  % bring it into focus
	  figure(display_fig)
	end
	return
      else
	% we have a valid figure, presumably one with menus
	set(display_fig,'vis','on')
	return
      end
    end

    % IF THIS FAR, THIS IS A *NEW* PLOT REQUEST 
    % CALLED DIRECTLY FROM UNPACK.
    if isempty(findfig('NVODS display'))
      % open a new display figure if needed!
      fontsize = 0;
      figsize = [0 0 0 0];
      colors = zeros(3,3);
      % generate a new figure
      dispmenu('start', fontsize, figsize, colors)
    end
    
    display_data = argin2; % argin2 is browse_whos
    display_data = display_data(:);
    get_variables = argin3;  % Parameters transfer: argin3 is browse_getvariables
    display_count = argin4;  % argin4 is browse_count
    display_metadata = argin5; % argin5 is browse_metadata

    % first, strip out 'Acknowledge', 'URL' and '_Units' from variable names
    for i = 1:size(display_data,1)
      sz = size(display_data(i).name,1);
      keepvar = zeros(sz,1);
      % This for-loop is to get rid of 'Rx_Acknowledge' , 'Rx_URL' 
      % and 'Rx_XXX_Units' in display_data(i).name
      % Also put 'none' at top of list in display_data(i).name
      for j = 1:sz
	if isempty(instr('_Acknowledge',display_data(i).name(j,:))) & ...
	      isempty(instr('_URL', display_data(i).name(j,:))) & ...
	      isempty(instr('_Units', display_data(i).name(j,:)))
	  keepvar(j) = 1;
	end
      end
      display_data(i).name = display_data(i).name(find(keepvar),:);
      % next, add in 'none' variable at top of list.
      display_data(i).name = strvcat('none', display_data(i).name);
      display_data(i).size = display_data(i).size(find(keepvar));
      display_data(i).size = [{0}; display_data(i).size];
      display_data(i).index = 0;
      display_data(i).acqno = display_count+i-1;
      display_data(i).getvariables = get_variables;
    end
     
    if isempty(char(display_data(:).name))
      set(cat(2, display_menu{[1:16 20]}), 'enable', 'off')  % Modified by Xin
      display_acq_urls = 0;
    elseif all(strcmp('none',cellstr(char(display_data(:).name))))
      set(cat(2, display_menu{[1:16 20]}), 'enable', 'off')   % Modified by Xin
      display_acq_urls = 0;
    else
      set(cat(2, display_menu{[1:16 20]}), 'enable', 'on')  % Modified by Xin
      set(display_menu{9}(3), 'label','Set Z-data')
      set(display_menu{9}(4), 'enable', 'off')
      display_data = display_data(:);
      display_acq_urls = size(display_data, 1);
    end

    if display_acq_urls > 0
      % we have one new valid download.
      if display_count == 1
	display_index = 1;
      else
	display_index = display_index + 1;
      end
      [display_data(:).index] = deal(display_index);

      if ~isfield(display_metadata, 'geopos')
	display_metadata.geopos = [0 0 0 0];
      end
      if ~isfield(display_metadata, 'axes')
	display_metadata.axes = cell(3,1);
      end
	
      % Rearrange the index order in display_metadata.geopos
      % to reflect the index order which loaddods will use in
      % popping the data into the user workspace.
      ND = size(display_metadata.axes,1);
      if ND > 2
	reorder = [1:ND];
	geopos = display_metadata.geopos;
	reorder = [reorder(ND-1:ND) fliplr(reorder(1:ND-2))];
	new_geopos = zeros(1,4);
	% these lines new -- bug fix 2003/06/19. dbyrne
	for i = 1:4
	  if geopos(i) > 0
	    new_geopos(i) = find(reorder == geopos(i));
	  end
	end
	display_metadata.geopos = new_geopos;
      end

      % store download history
      if display_index == 1
	all_display_metadata = {display_metadata};
      else
	all_display_metadata = [all_display_metadata; {display_metadata}];
      end
       
      % set/reset display choices for each plot
      [plotchoices(1:display_acq_urls)] = ...
	  deal(struct('all_flag', 0, 'click', 0, 'acqno', 1, ...
          'acqno_array', [0 0 0 0], ...
          'xyzzz', [0 0 0 0], 'x', 1, 'x_slice', '', 'x_slicesize', '', ...
          'y', 1, 'y_slice', '', 'y_slicesize', '', ...
          'z', 1, 'z_slice', '', 'z_slicesize', '', ...
          'zz', 1, 'zz_slice', '', 'zz_slicesize', '', ...
          'figure', 'figure', ...
          'plot_type', 'imagesc', 'clim', [], ...
  	  'cval', [], ...
	  'linestyle', '-', 'color', 'k', 'scale',1,...
	  'marker', 'none', 'shading', ...
	  'flat')); 
      plotchoices = plotchoices(:);

      % set up the Rxx selection menu
      str1 = deblank(get(display_menu{2},'string'));
      % clip the 'All' selection off the end
      str1 = str1(1:size(str1,1)-1,:); 
      for i = display_count:display_count+display_acq_urls-1
	str = sprintf('R%i_', i);
	str1 = strvcat(str1, str);
      end
      % add in the 'All' selection again
      str1 = strvcat(str1, 'All');
      % set the value at the most recently acquired URL
      set(display_menu{2},'string',str1,'value', ...
			size(str1,1)-1);
      
    else  % if display_acq_urls == 0
      plotchoices = struct([]);
      % clear strings
      set(cat(2, display_menu{5:8}),'string','')
      v = cat(1, display_menu{5:8});
      set(v(:,2),'value',1);
      set(v(:,3),'string','Full Downloaded size');
      set(display_menu{10}, 'value', 1)
      browse('enableclear')
      if nargin == 4
	return
      end
    end % end of if-else
       
    % finally, save the metadata
    if display_count == 1
      old_num_plots = 0;
      display_choices = plotchoices;
      all_display_data = display_data;
    else
      old_num_plots = size(display_choices,1);
      display_choices = [display_choices; plotchoices];
      all_display_data = [all_display_data; display_data];
    end
     
    str1 = deblank(get(display_menu{1}, 'string'));
    for i = display_count:1:display_count+display_acq_urls-1
      acqno = i;
      whichplot = i-display_count + 1 + old_num_plots;
      str = sprintf('plot%i', whichplot);
      display_choices(whichplot).acqno = acqno;
      str1 = strvcat(str1, str);
      set(display_menu{1}, 'string', str1, 'value', whichplot);
      % calling dispmenu case 1 will set all the buttons to
      % reasonable values.
      % now try to guess the most reasonable type
      % of plot for these data.  Plotinit does NOT set
      % the desired slice.
      [dods_err, dods_err_msg] = plotinit('initial', whichplot);
      if dods_err
	dodsmsg(dods_err_msg)
	dispmenu('reset')
	return
      end
      % this will *also* call plotinit, but should preserve
      % the auto-selected plot type and set the slice correctly
      dispmenu(1)
    end  % end of for-loop

    % enable the figure to be accessed from browse window
    browse('enabledisplay')
    % reveal the figure
    set(display_fig,'visible','on')
    % bring it into focus
    figure(display_fig)
	
   case 'fontsize'
    if isempty(findfig('NVODS display'))
	return
      end
      fontsize = argin2;
      set(cat(2, display_menu{[1:8 10:21]}), 'fontsize', fontsize)
      return
      
    case 'getfigpos'
      out1 = zeros(1,4);
      if isempty(findfig('NVODS display'))
	return
      end
      un = get(display_fig, 'units');
      set(display_fig, 'units', 'pixels');
      out1 = get(display_fig, 'pos');
      set(display_fig, 'units', un)
      return
    
    case 'getslice'
      whichplot = get(display_menu{1},'value');
      varnum = argin2;
      whichvar = get(display_menu{varnum}(2),'value');
      if whichplot == 0
	out1 = '';
	out2 = '';
	return
      end
      if display_choices(whichplot).all_flag
	varname = deblank(combo_display_name{whichvar});
	for i = 1:max(size(all_display_data))
	  k = strcmp(varname, cellstr(all_display_data(i).name));
	  if sum(k) > 0
	    acqindex = i;
	    whichvar = find(k);
	    break
	  end
	end
      else
	acqno = display_choices(whichplot).acqno;
	acqchoices = cat(1,all_display_data(:).acqno);
	acqindex = find(acqchoices == acqno);
	varname = deblank(all_display_data(acqindex).name(whichvar,:));
      end
            
      % get the variable
      if varnum == 5
	whichvar = display_choices(whichplot).x;
      elseif varnum == 6
	whichvar = display_choices(whichplot).y;
      elseif varnum == 7
	whichvar = display_choices(whichplot).z;
      elseif varnum == 8
	whichvar = display_choices(whichplot).zz;
      end
      
      % set the slice
      if strcmp(varname,'none')
	out1 = '';
	slice = '';
      else
	slice = get(display_menu{varnum}(5),'string');
	if varnum == 5
	  display_choices(whichplot).x_slice = slice;
	elseif varnum == 6
	  display_choices(whichplot).y_slice = slice;
	elseif varnum == 7
	  display_choices(whichplot).z_slice = slice;
	elseif varnum == 8
	  display_choices(whichplot).zz_slice = slice;
	end
             
	if isempty(instr(varname, slice))
	  str =[ 'Error: the selected variable is not included in ', ...
		'the slice!' ];
	  dodsmsg(str)
	  out1 = '';
	  slice = '';
	  set(display_menu{varnum}(5),'string','')
	  if varnum == 5
	    display_choices(whichplot).x_slice = '';
	  elseif varnum == 6
	    display_choices(whichplot).y_slice = '';
	  elseif varnum == 7
	    display_choices(whichplot).z_slice = '';
	  elseif varnum == 8
	    display_choices(whichplot).zz_slice = '';
	  end
	else
	  out1 = varname;
	  slice = [ 'browse_dims = size(' slice ');'];
	end
      end
      out2 = slice;
      
    case 'menu11'
      whichplot = get(display_menu{1},'value');
      % set color menu
      str = get(display_menu{11}(1),'string');
      val = 1;
      for i = 1:size(str,1);
	if strcmp(deblank(lower(str(i,:))), ...
	      display_choices(whichplot).color)
	  val = i;
	  break
	end
      end
      set(display_menu{11}(1), 'vis', 'on', 'value', val)
      set(display_menu{11}(2), 'vis', 'on')

    case 'menu12'
      whichplot = get(display_menu{1},'value');
      % set linestyle menu
      str = get(display_menu{12}(1),'string');
      val = 5;
      for i = 1:size(str,1);
	if strcmp(deblank(lower(str(i,:))), ...
	      display_choices(whichplot).linestyle)
	  val = i;
	  break
	end
      end
      set(display_menu{12}(1), 'vis', 'on', 'value', val)
      set(display_menu{12}(2), 'vis', 'on')
	
    case 'menu13'
      whichplot = get(display_menu{1},'value');
      % set marker menu
      str = get(display_menu{13}(1),'string');
      val = 1;
      for i = 1:size(str,1);
	if strcmp(deblank(lower(str(i,:))), ...
	      display_choices(whichplot).marker)
	  val = i;
	  break
	end
      end
      set(display_menu{13}(1), 'vis', 'on', 'value', val)
      set(display_menu{13}(2),'vis','on')
      
    case 'menu14'
      whichplot = get(display_menu{1},'value');
      % set shading menu
      str = get(display_menu{14}(1),'string');
      for i = 1:size(str,1);
	if strcmp(deblank(lower(str(i,:))), ...
	      display_choices(whichplot).shading)
	  break
	end
      end
      set(display_menu{14}(1), 'vis', 'on', 'value', i)
      set(display_menu{14}(2),'vis','on')
      
    case 'menu15'
      whichplot = get(display_menu{1},'value');
      % set color limits
      clim = display_choices(whichplot).clim;
      set(display_menu{15}(1),'vis', 'on', 'string', num2str(clim));
      set(display_menu{15}(2),'vis','on')
      
    case 'menu16'
      whichplot = get(display_menu{1},'value');
      % set color limits
      cval = display_choices(whichplot).cval;
      set(display_menu{16}(1),'vis', 'on', 'string', num2str(cval));
      set(display_menu{16}(2),'vis','on')
      
      % Code added by Xin Zhang
    
    case 'menu17'
      whichplot = get(display_menu{1},'value');
      scale = display_choices(whichplot).scale;
      set(display_menu{20}(1),'vis','on','string',num2str(scale));
      set(display_menu{20}(2), 'vis', 'on')
        
    case 'overplot'
      browse('overplot')
      return
        
    case 'setfigpos'
      if isempty(findfig('NVODS display'))
	return
      end

      % get figsize
      figsize = argin2;
      if any(figsize(3:4) == 0)
	% set up default figure size
	k = get(0,'units');
	set(0,'units','pixels')
	scr_size = get(0,'ScreenSize'); scr_offset = scr_size(1:2); 
	scr_size = scr_size(3:4);
	set(0,'units',k)
	fig_size = [460 540];
	fig_offset(1) = 100;
	fig_offset(2) = scr_size(2)*0.5;
	if fig_offset(2)+fig_size(2)+20 > scr_size(2),
	  fig_offset(2) = scr_size(2)-fig_size(2)-40; 
	end
	figsize = [fig_offset fig_size];
      end
      un = get(display_fig,'units');
      set(display_fig, 'units','pixels','pos', figsize)
      set(display_fig,'units',un);
      return
      
    case 'setslicesize'
      whichplot = get(display_menu{1},'value');
      if whichplot == 0
	return
      end
      varnum = argin2;
      dims = argin3;

      if varnum == 5
	display_choices(whichplot).x_slicesize = dims;
      elseif varnum == 6
	display_choices(whichplot).y_slicesize = dims;
      elseif varnum == 7
	display_choices(whichplot).z_slicesize = dims;
      elseif varnum == 8
	display_choices(whichplot).zz_slicesize = dims;
      end
      
      dimstr = 'Slice size: ';
      if all(~isnan(dims))
	set(cat(1,display_menu{[17 19]}),'enable','on')
	for i = 1:length(dims)
	  dimstr = [dimstr, sprintf('%i ', dims(i))];
	end
	c = get(display_menu{varnum}(4),'userdata');
	set(display_menu{varnum}(4), 'string', dimstr, ...
	    'foregroundcolor', c, 'fontweight','normal')
      else
	dimstr = '            NOT A VALID SLICE';
	set(cat(1,display_menu{[17 19]}),'enable','off')
	set(display_menu{varnum}(4), 'string', dimstr, ...
	    'foregroundcolor','r','fontweight','bold')
      end
    
    case 'setplotinfo'
        % this is used to set color, linestyle, marker, figure and etc ...
	% for 7 kinds of plots(plot,imagesc,..., quiver and polar)
        whichplot = get(display_menu{1},'value');
        plot_type = argin2;
                
        switch plot_type
        case 1 %plot
	  display_choices(whichplot).linestyle = '-';
	  display_choices(whichplot).marker = '.';
	  display_choices(whichplot).figure = 'figure';
	  set(display_menu{13}(1), 'value', 14);   % set marker menu as '.'
	  set(display_menu{12}(1), 'value', 1);    % set linestyle menu as '-'
	  set(display_menu{3}, 'value', 2);   %set figure as figure
        case 2  %imagesc
	  if ~isempty(instr('Longitude',display_choices(whichplot).x_slice)) &  ...
		~isempty(instr('Latitude',display_choices(whichplot).y_slice))
	    display_choices(whichplot).figure = 'browse_fig';
	    set(display_menu{3}, 'value', 1);   %set figure as browse_fig
	  else
	    display_choices(whichplot).figure = 'figure';
	    set(display_menu{3}, 'value', 2);   %set figure as figure
	  end
	case 3  %contour
	  if ~isempty(instr('Longitude',display_choices(whichplot).x_slice)) &  ...
		~isempty(instr('Latitude',display_choices(whichplot).y_slice))
	    display_choices(whichplot).figure = 'browse_fig';
	    set(display_menu{3}, 'value', 1);   %set figure as browse_fig
	  else
	    display_choices(whichplot).figure = 'figure';
	    set(display_menu{3}, 'value', 2);   %set figure as figure
	  end
	case 4  %contourf
	  if ~isempty(instr('Longitude',display_choices(whichplot).x_slice)) &  ...
		~isempty(instr('Latitude',display_choices(whichplot).y_slice))
	    display_choices(whichplot).figure = 'browse_fig';
	    set(display_menu{3}, 'value', 1);   %set figure as browse_fig
	  else
	    display_choices(whichplot).figure = 'figure';
	    set(display_menu{3}, 'value', 2);   %set figure as figure
	  end
	case 5  %pcolor
	  if ~isempty(instr('Longitude',display_choices(whichplot).x_slice)) &  ...
		~isempty(instr('Latitude',display_choices(whichplot).y_slice))
	    display_choices(whichplot).figure = 'browse_fig';
	    set(display_menu{3}, 'value', 1);   %set figure as browse_fig
	  else
	    display_choices(whichplot).figure = 'figure';
	    set(display_menu{3}, 'value', 2);   %set figure as figure
	  end
	case 6  %quiver
	  display_choices(whichplot).linestyle = '-';
	  set(display_menu{12}(1), 'value', 1);    % set linestyle as -

	  if ~isempty(instr('Longitude',display_choices(whichplot).x_slice)) &  ...
		~isempty(instr('Latitude',display_choices(whichplot).y_slice))
	    display_choices(whichplot).figure = 'browse_fig';
	    set(display_menu{3}, 'value', 1);   %set figure as browse_fig
	  else
	    display_choices(whichplot).figure = 'figure';
	    set(display_menu{3}, 'value', 2);   %set figure as figure
	  end
                  
        case 7  %polar
	  display_choices(whichplot).figure = 'figure';
	  set(display_menu{3}, 'value', 2);   %set figure as figure
      end
        
    case 'setnewvar'
      % this is when var is set by clicking on a new variable
      varnum = argin2;
      whichplot = get(display_menu{1},'value');
      whichvar = get(display_menu{varnum}(2),'value');
      % this function resets whichvar and acqno for 'All' selection
      [acqindex, whichvar, varname] = isall('set', whichplot, whichvar);
      % Following line added by Xin Zhang Nov.28 2002
      plot_type = get(display_menu{10},'value');
      
      % take care of 'All' selection
      if display_choices(whichplot).all_flag
	display_choices(whichplot).acqno_array(varnum - 4) = acqindex;
	display_choices(whichplot).xyzzz(varnum - 4) = whichvar;
      end
	
      if varnum == 5
	display_choices(whichplot).x = whichvar;
      elseif varnum == 6
	display_choices(whichplot).y = whichvar;
      elseif varnum == 7
	display_choices(whichplot).z = whichvar;
      elseif varnum == 8
	display_choices(whichplot).zz = whichvar;
      end
      
      % catch 'none' settings first
      if strcmp(varname,'none')
	slice = '';
	fullstr = 'Full Downloaded size: ';
	set(display_menu{varnum}(3),'string', fullstr);
	dimstr = 'Slice size: ';
	set(display_menu{varnum}(4),'string', dimstr);
	set(display_menu{varnum}(5),'string', slice);
	set(display_menu{varnum}(5),'enable','off')
	return
      else
	set(display_menu{varnum}(5),'enable','on')
      end

      % now set slice selection based on varname and type
      % of plot, and allowable plot figures based on plotchoices.
      if varnum == 5
	if plot_type == 1 | plot_type == 7
	  % Following added by Xin Nov.28 2002  If the plot_type is
	  % Plot or Polar we make the slice as varname(:)	  
	  % Should we also set the default figure to new fig?
	  slice = [varname '(:)'];
	else
	  slice = varname;
	end

	if isempty(instr('Longitude', varname))
	  if strcmp(display_choices(whichplot).figure,'browse_fig');
	    display_choices(whichplot).figure = 'figure';
	    set(display_menu{3}, 'value', 2)
	    set(display_menu{4}, 'vis', 'off')
	  end
	else
	  yname = all_display_data(acqindex).name(display_choices(whichplot).y,:);
	  if ~isempty(instr('Latitude', yname))
	    display_choices(whichplot).figure = 'browse_fig';
	    set(display_menu{3}, 'value', 1)
	    set(display_menu{4}, 'vis', 'off')
	  else
	    if strcmp(display_choices(whichplot).figure,'browse_fig');
	      display_choices(whichplot).figure = 'figure';
	      set(display_menu{3}, 'value', 2)
	      set(display_menu{4}, 'vis', 'off')
	    end
	  end
	end
      
      elseif varnum == 6
	if plot_type == 1 | plot_type == 7
	  % Following added by Xin Nov.28 2002  If the plot_type is
	  % Plot or Polar we make the slice as varname(:)	  
	  % Should we also set the default figure to new fig?
	  slice = [varname '(:)'];
	else
	  slice = varname;
	end
	if isempty(instr('Latitude', varname))
	  if strcmp(display_choices(whichplot).figure,'browse_fig');
	    display_choices(whichplot).figure = 'figure';
	    set(display_menu{3},'value',2)
	    set(display_menu{4},'vis','off')
	  end
	else
	  xname = all_display_data(acqindex).name(display_choices(whichplot).x,:);
	  if ~isempty(instr('Longitude', xname))
	    display_choices(whichplot).figure = 'browse_fig';
	    set(display_menu{3},'value',1)
	    set(display_menu{4},'vis','off')
	  else
	    if strcmp(display_choices(whichplot).figure,'browse_fig');
	      display_choices(whichplot).figure = 'figure';
	      set(display_menu{3},'value',2)
	      set(display_menu{4},'vis','off')
	    end
	  end
	end

      elseif varnum == 7
	if manydims(whichvar,acqindex)
	  slice = setsqueeze(whichvar, whichplot, acqindex);
	else
	  slice = varname;
	end
      elseif varnum == 8
	if manydims(whichvar,acqindex)
	  slice = setsqueeze(whichvar, whichplot, acqindex);
	else
	  slice = varname;
	end
          
      end
      set(display_menu{varnum}(5),'string', slice);
            
      fullstr = 'Full Downloaded size: ';
      dims = all_display_data(acqindex).size{whichvar};      
      for i = 1:length(dims)
	fullstr = [fullstr, sprintf('%i ', dims(i))];
      end
      set(display_menu{varnum}(3),'string', fullstr);

      % Using evalin() to call dispmenu('setslicesize',varnum) to set slicesize
      callbackstring = sprintf('%s%i%s%i%s%i%s%i%s', ...
	  '[browse_var, browse_slice] =  dispmenu(''getslice'',', ...
	    varnum, ...
	  [ '); if ~isempty(browse_slice), ', ...
	      'if exist(browse_var) == 1, browse_dims = nan; ', ...
	      'eval(browse_slice, ''% put error message here'');', ...
	      'dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', browse_dims), else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; clear browse_slice browse_var browse_dims']);
      evalin('base',callbackstring)
      
    case 'setvar'
      % this is when var is set by changing the plot number
      % In case-'setvar' This part of code is responsible for set the
      % proper vectors of number for Slice size and
      % Full Downloaded size and also the proper string in edit box
      % corresponding to X-data,Y-data,U-data and V-data
      varnum = argin2;
      whichplot = get(display_menu{1},'value');
      whichvar = get(display_menu{varnum}(2),'value');
      % this function resets whichvar and acqno for 'All' selection
      [acqindex, whichvar, varname] = isall('set', whichplot, whichvar);
      % Following line added by Xin Zhang Nov.28 2002
      plot_type = get(display_menu{10},'value');

      % catch 'none' settings first
      if strcmp(varname,'none')
	%slice = '';
	%fullstr = 'Full Downloaded size: ';
	%set(display_menu{varnum}(3),'string', fullstr);
	%dimstr = 'Slice size: ';
	%set(display_menu{varnum}(4),'string', dimstr);
	%set(display_menu{varnum}(5),'string', slice);
	set(display_menu{varnum}(5),'enable','off')
	return
      else
	set(display_menu{varnum}(5),'enable','on')
      end
                  
      if varnum == 5
	if plot_type == 1 | plot_type == 7
	  if isempty(instr('(:)',display_choices(whichplot).x_slice))
	    slice = [display_choices(whichplot).x_slice '(:)'];
	  else
	    slice = display_choices(whichplot).x_slice;
	  end
	else
	  slice = display_choices(whichplot).x_slice;
	end
	slicesize = display_choices(whichplot).x_slicesize;
      elseif varnum == 6
	if plot_type == 1 | plot_type == 7
	  if isempty(instr('(:)',display_choices(whichplot).y_slice))
	    slice = [display_choices(whichplot).y_slice '(:)'];
	  else
	    slice = display_choices(whichplot).y_slice;
	  end
	else
	  slice = display_choices(whichplot).y_slice;
	end
	slicesize = display_choices(whichplot).y_slicesize;
      elseif varnum == 7
	slicesize = display_choices(whichplot).z_slicesize;
	if manydims(whichvar,acqindex)
	  slice = setsqueeze(whichvar, whichplot, acqindex);
	else
	  slice = varname;
	end
      elseif varnum == 8
	slicesize = display_choices(whichplot).zz_slicesize;
	if manydims(whichvar,acqindex)
	  slice = setsqueeze(whichvar, whichplot, acqindex);
	else
	  slice = varname;
	end
      end
      set(display_menu{varnum}(5),'string', slice);
      fulldims = all_display_data(acqindex).size{whichvar};
      if isempty(slice)
          slicedims = fulldims;
      else
          slicedims = slicesize;
      end
      
      dimstr = 'Slice size: ';
      fullstr = 'Full Downloaded size: ';
      for i = 1:length(fulldims)
	fullstr = [fullstr, sprintf('%i ', fulldims(i))];
      end
      set(display_menu{varnum}(3),'string', fullstr);
      
      for i = 1:length(slicedims)
	dimstr = [dimstr, sprintf('%i ', slicedims(i))];
      end
      set(display_menu{varnum}(4),'string', dimstr);
      
    case 'start'
      % prevent multiple startups
      closefig('NVODS display')
      
      % initialize variables
      display_choices = struct('all_flag', 0, 'click', 0, 'acqno', 1, ...
	  'acqno_array', [0 0 0 0],...
	  'xyzzz', [0 0 0 0], 'x', 1, 'x_slice', '', 'x_slicesize', '', ...
	  'y', 1, 'y_slice', '', 'y_slicesize', '', ...
	  'z', 1, 'z_slice', '', 'z_slicesize', '', ...
	  'zz', 1, 'zz_slice', '', 'zz_slicesize', '', ...
	  'figure', 'figure', ...
	  'plot_type', 'imagesc', 'clim', [], ...
	  'cval', [], ...
	  'linestyle', '-', 'color', 'k','scale',1, ...
	  'marker', 'none', 'shading', ...
	  'flat');
      display_choices = display_choices([]);
      
      % protective startup!  If we are regenerating the figure,
      % but data downloads have already occured, do not destroy
      % the data and metadata
      if isempty(display_index)
	all_display_data = struct([]);
	all_display_metadata = {[]};
	display_index = 0;
      end

      % get fontsize
      fontsize = argin2;
      if fontsize == 0
	fontsize = browse('getfontsize');
      end
      
      % get figsize
      figpos = argin3;
      % THE EDIT FIGURE
      if any(figpos(3:4) == 0)
	figpos = browse('figpos',3);
      end

      if any(figpos(3:4) == 0)
	% set up default figure size
	un = get(0,'units');
	set(0,'units','pixels')
	scr_size = get(0,'ScreenSize'); 
	scr_size = scr_size(3:4);
	set(0,'units', un)
	fig_size = [460 540];
	fig_offset(1) = 100;
	fig_offset(2) = scr_size(2)*0.5;
	if fig_offset(2)+fig_size(2)+20 > scr_size(2),
	  fig_offset(2) = scr_size(2)-fig_size(2)-40; 
	end
	figpos = [fig_offset fig_size];
      end

      % get colors
      colors = argin4;
      if all(colors == 0) | ~all(size(colors == [3 3]))
	colors = browse('getcolors');
	colors = colors([6 1 5],:);
      end
      
      % initialize some values for figures
      display_menu = cell(10,1);

      buttonpos = [0.01 0.95 0.5 0.05];
      indent = 0.05;
      buttonsep = 0.05;
      
      % set up the figure
      display_fig = figure('numbertitle','off', ...
	  'Name','Display acquired data', ...
	  'visible','off', ...
	  'interruptible','off', ...
	  'units','pixels', ...
	  'resize','off',...
	  'userdata','NVODS display', ...
	  'color', colors(1,:), ...
	  'menubar', 'none', ...
	  'position', figpos);
      
      % set up the uimenu
      display_menu{9}(1) = uimenu(display_fig,'label','Edit');
      display_menu{9}(2) = uimenu(display_fig, 'label', ...
	  'Apply to All', 'enable', 'on');
      uimenu(display_menu{9}(1),'label','Add New Plot','callback', ...
	  'dispmenu(''addplot'')');
      uimenu(display_menu{9}(1),'label','Delete Plot', 'callback', ...
	  'dispmenu(''delplot'')');
      uimenu(display_menu{9}(1),'label','Delete All Plots', 'callback', ...
	  'dispmenu(''delall'')');
      uimenu(display_menu{9}(2),'label','Set Plot Type', ...
	  'callback', 'dispmenu(''applytoall'',''plot'')', 'enable', 'on');
      uimenu(display_menu{9}(2),'label','Set X-data', ...
	  'callback', 'dispmenu(''applytoall'', 5)', 'enable', 'on');
      uimenu(display_menu{9}(2),'label','Set Y-data', ...
	  'callback', 'dispmenu(''applytoall'',6)', 'enable', 'on');
      display_menu{9}(3) = uimenu(display_menu{9}(2),'label','Set Z-data', ...
	  'callback', 'dispmenu(''applytoall'', 7)', 'enable', 'on');
      display_menu{9}(4) = uimenu(display_menu{9}(2),'label','Set V-data', ...
	  'callback', 'dispmenu(''applytoall'', 8)', 'enable', 'on');
      
      % set up basic button dimensions
      buttonheight = 0.06;
      buttonwidth = 0.1;
      buttonsep = 0.02;
      
      %%%%%%%%%%%%%%%%%%  FRAME 1 %%%%%%%%%%%%%%%%%%%%%%%%%
      frame1pos = [0 0.7 0.17 0.3];
      uicontrol('Units','norm', ...
	  'Style','frame', ...
	  'backgroundcolor', colors(2,:), ...
	  'Position', frame1pos)
  
      % Inside frame 1: plot number list
      list1title = [frame1pos(1)+0.02 ...
	    frame1pos(2)+frame1pos(4)-0.02-buttonheight ...
	    1.2*buttonwidth buttonheight];
      list1pos = [frame1pos(1)+0.02 frame1pos(2)+0.02 ...
	    frame1pos(3)-0.04 frame1pos(4)-0.04-buttonheight-buttonsep];
      str = sprintf('%s\n%s','Plot','Number');
      uicontrol('units','norm','style','text', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'position', list1title, ...
	  'horiz','center', ...
	  'max', 2, ...
	  'tooltip', 'Select which plot to modify', ...
	  'string', str)
      display_menu{1} = uicontrol('Units','norm', ...
	  'Position', list1pos, ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'String','', ...
	  'callback','dispmenu(1)', ...
	  'Style','listbox');
      %%%%%%%%%%%%%%%%%%  END FRAME 1 %%%%%%%%%%%%%%%%%%%%%%%%%
      
      %%%%%%%%%%%%%%%%%%  FRAME 2 %%%%%%%%%%%%%%%%%%%%%%%%%
      % top row: acq #, plot type, plot options, window
      frame2pos = [0.17 0.7 0.83 0.3];
      uicontrol('Units','norm', ...
	  'Style','frame', ...
	  'backgroundcolor', colors(2,:), ...
	  'Position', frame2pos)
      
  
      % inside frame 2: list of acquisitions 
      list2title = [frame2pos(1)+0.02 ...
	    frame2pos(2)+frame2pos(4)-0.02-buttonheight ...
	    1.3*buttonwidth buttonheight];
      list2pos = [frame2pos(1)+0.02 frame2pos(2)+0.02 ...
	    0.11 frame2pos(4)-0.04-buttonheight-buttonsep];
      str = sprintf('%s\n%s','Acquisition','Number');
      uicontrol('units','norm','style','text', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'position', list2title, ...
	  'horiz','center', ...
	  'max', 2, ...
	  'tooltip', 'Select which data download to plot', ...
	  'string', str)
      display_menu{2} = uicontrol('Units','norm', ...
	  'Position', list2pos, ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'String','', ...
	  'callback','dispmenu(2)', ...
	  'Style','listbox');
      
      % inside frame 2: plot type menu 
      list3title = [0.32 frame2pos(2)+frame2pos(4)-0.02-buttonheight ...
	    1.2*buttonwidth buttonheight];
      list3pos = [0.32 frame2pos(2)+0.02 ...
	    0.16 frame2pos(4)-0.04-buttonheight-buttonsep];
      str = sprintf('%s\n%s','Plot','Type');
      uicontrol('Units','norm', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'Position', list3title, ...
	  'max', 2, ...
	  'String', str, ...
	  'tooltip', 'Select the Matlab plot command to use', ...
	  'horiz','center', ...
	  'Style','text');
      display_menu{10} = uicontrol('Units','norm', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'Position', list3pos, ...
	  'value', 2, ... 
	  'callback','dispmenu(10)', ...
	  'String', 'Plot|Imagesc|Contour|Contourf|Pcolor|Quiver|Polar', ...
	  'Style','listbox');
      
      % inside frame 2: special plot characteristic menus
      stretch = 1.5;
      menu1 = str2mat('default', 'y', 'm', 'c', 'r', 'g', 'b', 'w', ...
	  'k');
      menu1pos = [0.52 1-1.5*buttonheight-0.02 ...
	    stretch*buttonwidth buttonheight];
      menu1title = [0.52 1-buttonheight/2-0.02 ...
	    stretch*buttonwidth buttonheight/2];

      menu2 = str2mat('-','--',':','-.','none');
      menu2pos = [1-0.02-stretch*buttonwidth ...
	    1-1.5*buttonheight-0.02 ...
	    stretch*buttonwidth buttonheight];
      menu2title = [1-0.02-stretch*buttonwidth ...
	    1-buttonheight/2-0.02 ...
	    stretch*buttonwidth buttonheight/2];
      
      menu3 = str2mat('none', '+', 'o', 'x', '*', 's', 'd', 'v', ...
	  '^', '<', '>', 'p', 'h', '.');
      menu3pos = [0.52 frame2pos(2)+frame2pos(4)/3-buttonheight/2 ...
	    stretch*buttonwidth buttonheight];
      menu3title = [0.52 frame2pos(2)+frame2pos(4)/3+buttonheight/2 ...
	    stretch*buttonwidth buttonheight/2];

      menu4 = str2mat('flat','faceted','interp');
      menu4pos = [1-0.02-stretch*buttonwidth ...
	     frame2pos(2)+frame2pos(4)/3-buttonheight/2 ...
	     stretch*buttonwidth buttonheight];
      menu4title = [1-0.02-stretch*buttonwidth ...
	    frame2pos(2)+frame2pos(4)/3+buttonheight/2 ...
	    stretch*buttonwidth buttonheight/2];
      
      menu5pos = [0.6 frame2pos(2)+frame2pos(4)/3-buttonheight/2 ...
	    stretch*buttonwidth buttonheight];
      menu5title = [0.52 frame2pos(2)+frame2pos(4)/3+buttonheight/2 ...
	    2*stretch*buttonwidth buttonheight/2];

      display_menu{11}(1) = uicontrol('Units','norm', ...
	  'position', menu1pos, ...
	  'String',menu1, ...
	  'visible','off', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'callback', 'dispmenu(11)', ...
	  'Style','popupmenu', ...
	  'Value',9);
      display_menu{11}(2) = uicontrol('Units','norm', ...
	  'position', menu1title, ...
	  'String','Color', ...
	  'tooltip', 'line and symbol color', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'horiz','left', ...
	  'Style','text');

      display_menu{12}(1) = uicontrol('Units','norm', ...
	  'position', menu2pos, ...
	  'String',menu2, ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'callback', 'dispmenu(12)', ...
	  'Style','popupmenu', ...
	  'Value',1);
      display_menu{12}(2) = uicontrol('Units','norm', ...
	  'position', menu2title, ...
	  'String','Linestyle', ...
	  'tooltip', '', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'horiz','left', ...
	  'Style','text');
      display_menu{13}(1) = uicontrol('Units','norm', ...
	  'position', menu3pos, ...
	  'String',menu3, ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'callback', 'dispmenu(13)', ...
	  'Style','popupmenu', ...
	  'Value',1);
      display_menu{13}(2) = uicontrol('Units','norm', ...
	  'position', menu3title, ...
	  'String','Marker', ...
	  'tooltip', 'select the plot symbol', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'horiz','left', ...
	  'Style','text');
      display_menu{14}(1) = uicontrol('Units','norm', ...
	  'position', menu4pos, ...
	  'String', menu4, ...
	  'visible','off', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'callback', 'dispmenu(14)', ...
	  'Style','popupmenu', ...
	  'Value',1);
      display_menu{14}(2) = uicontrol('Units','norm', ...
	  'position', menu4title, ...
	  'String','Shading', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'horiz','left', ...
	  'Style','text');
      display_menu{15}(1) = uicontrol('Units','norm', ...
	  'position', menu5pos, ...
	  'String', '', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(3,:), ...
	  'visible','on', ...
	  'horiz', 'left', ...
	  'callback', 'dispmenu(15)', ...
	  'Style','edit');
      display_menu{15}(2) = uicontrol('Units','norm', ...
	  'position', menu5title, ...
	  'String','Color limits (in data units)', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','on', ...
	  'tooltip', 'default limits: entire data range', ...
	  'horiz','left', ...
	  'Style','text');
      display_menu{16}(1) = uicontrol('Units','norm', ...
	  'position', menu5pos, ...
	  'String', '', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(3,:), ...
	  'visible','off', ...
	  'horiz', 'left', ...
	  'callback', 'dispmenu(16)', ...
	  'Style','edit');
      display_menu{16}(2) = uicontrol('Units','norm', ...
	  'position', menu5title, ...
	  'String','Contour number or levels', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'tooltip', 'default autoselects number of contours and their levels ', ...
	  'horiz','left', ...
	  'Style','text');
  
      % Code added by Xin Zhang 2002 Fall  (display_menu{20} for scale in quiver)
      display_menu{20}(1) = uicontrol('Units','norm', ...
	  'position', menu5pos, ...
	  'String', '1', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(3,:), ...
	  'visible','off', ...
	  'horiz', 'left', ...
	  'callback', 'dispmenu(20)', ...
	  'Style','edit');
      display_menu{20}(2) = uicontrol('Units','norm', ...
	  'position', menu5title, ...
	  'String','Scale', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'tooltip', 'Scale of arrows in Quiver', ...
	  'horiz','left', ...
	  'Style','text');
      % End of Code added by Xin Zhang
      
      % inside frame 2: control choice of display window 
      popup1pos = [0.52 frame2pos(2)+0.01 ...
	    0.5-buttonwidth-buttonsep-0.04 buttonheight];
      edit1pos = [popup1pos(1)+popup1pos(3)+0.02 popup1pos(2) ...
	    buttonwidth buttonheight];
      str = str2mat('Display on browse window', ...
	  'Display on new window', 'Display on window:');
      display_menu{3} = uicontrol('Units','norm', ...
	  'Position', popup1pos, ...
	  'String', str, ...
	  'value', 1, ...
	  'tooltip', 'Select the destination figure', ...
	  'callback', 'dispmenu(3)', ...
	  'Style','popup');
      display_menu{4} =  uicontrol('Units','norm', ...
	  'Position', edit1pos, ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(3,:), ...
	  'callback', 'dispmenu(4)', ...
	  'Style','edit', 'visible', 'off');
      %%%%%%%%%%%%%%%%%% END FRAME 2 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
      %%%%%%%%%%%%%%%%%% FRAME 3 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % bottom row: selected variables and slices
      frame3pos = [0 0.1 1 0.6];
      uicontrol('Style','frame', ...
	  'units','norm', ...
	  'backgroundcolor', colors(2,:), ...
	  'Position', frame3pos)
     
      % variables lists inside frame 3
      top = frame3pos(2)+frame3pos(4);
      lw = 0.5-buttonwidth-buttonsep-0.02;
      lx1 = frame3pos(1)+0.02;
      lx2 = lx1+buttonwidth+buttonsep;
      lx3 = lx2+lw+buttonsep;
      lh = frame3pos(4)/4;
      
      label5pos = [lx1 top-lh/2 buttonwidth buttonheight/2];
      list5pos = [lx2 top-lh+0.0125 lw lh-0.025];
      slice5dimpos = [lx3 top-0.0125-buttonheight/2 1-lx3-0.02 buttonheight/2];
      slice5pos = [lx3 label5pos(2)-0.025 1-lx3-0.02 buttonheight];
      dim5pos = [lx3 list5pos(2) 1-lx3-0.02 buttonheight/2];

      label6pos = [lx1 top-1.5*lh buttonwidth buttonheight/2];
      list6pos = [lx2 top-2*lh+0.0125 lw lh-0.025];
      slice6dimpos = [lx3 top-lh-0.0125-buttonheight/2 1-lx3-0.02 buttonheight/2];
      slice6pos = [lx3 label6pos(2)-0.025 1-lx3-0.02 buttonheight];
      dim6pos = [lx3 list6pos(2) 1-lx3-0.02 buttonheight/2];

      label7pos = [lx1 top-2.5*lh buttonwidth buttonheight/2];
      list7pos = [lx2 top-3*lh+0.0125 lw lh-0.025];
      slice7dimpos = [lx3 top-2*lh-0.0125-buttonheight/2 1-lx3-0.02 buttonheight/2];
      slice7pos = [lx3 label7pos(2)-0.025 1-lx3-0.02 buttonheight];
      dim7pos = [lx3 list7pos(2) 1-lx3-0.02 buttonheight/2];

      label8pos = [lx1 top-3.5*lh buttonwidth buttonheight/2];
      list8pos = [lx2 top-4*lh+0.0125 lw lh-0.025];
      slice8dimpos = [lx3 top-3*lh-0.0125-buttonheight/2 1-lx3-0.02 buttonheight/2];
      slice8pos = [lx3 label8pos(2)-0.025 1-lx3-0.02 buttonheight];
      dim8pos = [lx3 list8pos(2) 1-lx3-0.02 buttonheight/2];
      
      % All of the variable selection controls
      display_menu{5}(1) = uicontrol('Units','norm', ...
	  'Position', label5pos, ...
	  'String','X-data', ...
	  'tooltip', 'Select data for the x-axis', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'Style','text');
      display_menu{5}(2) = uicontrol('Units','norm', ...
	  'Position', list5pos, ...
	  'String','', ...
	  'callback', 'dispmenu(5)', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'value', 1, ...
	  'Style','listbox');
      display_menu{5}(3) = uicontrol('Units','norm', ...
	  'Position', dim5pos, ...
	  'String','Full Downloaded Size:', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'horiz','left', ...
	  'Style','text');
      display_menu{5}(4) = uicontrol('Units','norm', ...
	  'Position', slice5dimpos, ...
	  'String','Slice size:', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'userdata',  colors(1,:), ...
	  'horiz','left', ...
	  'Style','text');
      varnum = 5;
      callbackstring = sprintf('%s%i%s%i%s%i%s%i%s', ...
	  '[browse_var, browse_slice] =  dispmenu(''getslice'',', ...
	    varnum, ...
	  [ '); if ~isempty(browse_slice), ', ...
	      'if exist(browse_var) == 1, browse_dims = nan; ', ...
	      'eval(browse_slice, ''% put error message here'');', ...
	      'dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', browse_dims), else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; clear browse_slice browse_var browse_dims']);
      display_menu{5}(5) = uicontrol('Units','norm', ...
	  'Position', slice5pos, ...
	  'String','', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(3,:), ...
	  'horiz','left', ...
	  'callback', callbackstring, ...
	  'Style','edit');
      display_menu{6}(1) = uicontrol('Units','norm', ...
	  'Position', label6pos, ...
	  'tooltip', 'Select data for the y-axis', ...
	  'String','Y-data', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'Style','text');
      display_menu{6}(2) = uicontrol('Units','norm', ...
	  'Position', list6pos, ...
	  'String','', ...
	  'callback', 'dispmenu(6)', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'value', 1, ...
	  'Style','listbox');
      display_menu{6}(3) = uicontrol('Units','norm', ...
	  'Position', dim6pos, ...
	  'String','Full Downloaded Size:', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'horiz','left', ...
	  'Style','text');
      display_menu{6}(4) = uicontrol('Units','norm', ...
	  'Position', slice6dimpos, ...
	  'String','Slice size:', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'userdata',  colors(1,:), ...
	  'horiz','left', ...
	  'Style','text');
      varnum = 6;
      callbackstring = sprintf('%s%i%s%i%s%i%s%i%s', ...
	  '[browse_var, browse_slice] =  dispmenu(''getslice'',', ...
	    varnum, ...
	  [ '); if ~isempty(browse_slice), ', ...
	      'if exist(browse_var) == 1, browse_dims = nan; ', ...
	      'eval(browse_slice, ''% put error message here'');', ...
	      'dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', browse_dims), else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; clear browse_slice browse_var browse_dims']);
      display_menu{6}(5) = uicontrol('Units','norm', ...
	  'Position', slice6pos, ...
	  'String','', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(3,:), ...
	  'horiz','left', ...
	  'callback', callbackstring, ...
	  'Style','edit');
      display_menu{7}(1) = uicontrol('Units','norm', ...
	  'Position', label7pos, ...
	  'String','Z-data', ...
	  'tooltip', 'Select the data to be imaged/contoured', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','on', ...
	  'Style','text');
      display_menu{7}(2) = uicontrol('Units','norm', ...
	  'Position', list7pos, ...
	  'String','', ...
	  'callback', 'dispmenu(7)', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','on', ...
	  'value', 1, ...
	  'Style','listbox');
      display_menu{7}(3) = uicontrol('Units','norm', ...
	  'Position', dim7pos, ...
	  'String','Full Downloaded Size:', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'horiz','left', ...
	  'Style','text');
      display_menu{7}(4) = uicontrol('Units','norm', ...
	  'Position', slice7dimpos, ...
	  'String','Slice size:', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'userdata',  colors(1,:), ...
	  'horiz','left', ...
	  'Style','text');
      varnum = 7;
      callbackstring = sprintf('%s%i%s%i%s%i%s%i%s', ...
	  '[browse_var, browse_slice] =  dispmenu(''getslice'',', ...
	    varnum, ...
	  [ '); if ~isempty(browse_slice), ', ...
	      'if exist(browse_var) == 1, browse_dims = nan; ', ...
	      'eval(browse_slice, ''% put error message here'');', ...
	      'dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', browse_dims), else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; clear browse_slice browse_var browse_dims']);
      display_menu{7}(5) = uicontrol('Units','norm', ...
	  'Position', slice7pos, ...
	  'String','', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(3,:), ...
	  'horiz','left', ...
	  'callback', callbackstring, ...
	  'Style','edit');
      display_menu{8}(1) = uicontrol('Units','norm', ...
	  'Position', label8pos, ...
	  'String','V-data', ...
	  'tooltip', 'Select the y-component of the data vector', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'Style','text');
      display_menu{8}(2) = uicontrol('Units','norm', ...
	  'Position', list8pos, ...
	  'String','', ...
	  'callback', 'dispmenu(8)', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'visible','off', ...
	  'value', 2, ...
	  'Style','listbox');
      display_menu{8}(3) = uicontrol('Units','norm', ...
	  'Position', dim8pos, ...
	  'String','Full Downloaded Size:', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'horiz','left', ...
	  'visible','off', ...
	  'Style','text');
      display_menu{8}(4) = uicontrol('Units','norm', ...
	  'Position', slice8dimpos, ...
	  'String','Slice size:', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(2,:), ...
	  'userdata',  colors(1,:), ...
	  'horiz','left', ...
	  'visible','off', ...
	  'Style','text');
      varnum = 8;
      callbackstring = sprintf('%s%i%s%i%s%i%s%i%s', ...
	  '[browse_var, browse_slice] =  dispmenu(''getslice'',', ...
	    varnum, ...
	  [ '); if ~isempty(browse_slice), ', ...
	      'if exist(browse_var) == 1, browse_dims = nan; ', ...
	      'eval(browse_slice, ''% put error message here'');', ...
	      'dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', browse_dims), else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; else, dispmenu(''setslicesize'',' ], ...
	    varnum, ...
	  [ ', 0); end; clear browse_slice browse_var browse_dims']);
      display_menu{8}(5) = uicontrol('Units','norm', ...
	  'Position', slice8pos, ...
	  'String','', ...
	  'foregroundcolor', colors(1,:), ...
	  'backgroundcolor', colors(3,:), ...
	  'horiz','left', ...
	  'visible','off', ...
	  'callback', callbackstring, ...
	  'Style','edit');
      %%%%%%%%%%%%%%%%%% END FRAME 3 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
      %%%%%%%%%%%%%%%%%% FRAME 4 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % Frame for Ok Cancel and Apply
      frame4pos = [0 0 1 0.1];
      uicontrol('Units','norm', ...
	  'Position', frame4pos, ...
	  'backgroundcolor', colors(2,:), ...
	  'Style','frame')
      
      X_width = 1.55;
      % inside frame 4 -- PLOT SELECTED, CANCEL, PLOT ALL
      button5pos = [frame4pos(1)+0.02 ...
	    frame4pos(2)+frame4pos(4)/2-buttonheight/2 ...
	    X_width*buttonwidth buttonheight];
      button6pos = [frame4pos(1)+frame4pos(3)-4.5*X_width*buttonwidth ...
	    frame4pos(2)+frame4pos(4)/2-buttonheight/2 ...
	    X_width*buttonwidth buttonheight];
      button7pos = [frame4pos(1)+frame4pos(3)-3*X_width*buttonwidth ...
	    frame4pos(2)+frame4pos(4)/2-buttonheight/2 ...
	    X_width*buttonwidth buttonheight];
      button8pos = [frame4pos(1)+frame4pos(3)-1.5*X_width*buttonwidth ...
	    frame4pos(2)+frame4pos(4)/2-buttonheight/2 ...
	    X_width*buttonwidth buttonheight];

      display_menu{21} = uicontrol('Units','norm', ...
	  'Position', button5pos, ...
	  'String', 'Overplot',...
	  'value', 0, ...
	  'tooltip', 'Overplot on browse window',...
	  'callback', 'dispmenu(''overplot'')', ...
	  'Style','toggle');
      
      display_menu{17} = uicontrol('Units','norm', ...
	  'Position', button6pos, ...
	  'callback', 'dispmenu(17)', ...
	  'String','Plot Selected');
      display_menu{18} = uicontrol('Units','norm', ...
	  'Position', button8pos, ...
	  'callback', 'dispmenu(18)', ...
	  'String','Cancel');
      display_menu{19} = uicontrol('Units','norm', ...
	  'Position', button7pos, ...
	  'callback', 'dispmenu(19)', ...
	  'String','Plot All');

      % disable all of the buttons
      set(cat(2, display_menu{[1:16 20]}),'enable','off')
            
      return
      %%%%%%%%%%%%%%%%%% END FRAME 4 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
    case 'reset'
      %disp('You are now in dispmenu reset')
      if isempty(findfig('NVODS display'))
	return
      end

      all_display_data = all_display_data([]);
      all_display_metadata = {[]};
      display_choices = display_choices([]);
      set(display_menu{1},'string','','value',0)
      set(display_menu{2},'string','','value',0)
      set(cat(2, display_menu{[1:16 20]}),'enable','off')
  
  end 
  % end of string arguments: display the figure!

else % argin1 is not a string
  % These numeric arguments are ONLY called by dispmenu figure
  % buttons, so no check for figure existence is necessary.

  % call of dispmenu(number) entry here, number is from 1 to 19
  % 1 --- Select Plot
  % 2 --- Select acqisition number
  % 3 ---  4 ---  5 --- Set variable in X-data 
  % 6 --- Set variable in Y-data
  % 7 ---   Set variable in Z(U)-data
  % 8 --- Set variable in ZZ(V)-data 
  % 9 --- unused
  % 10 ---
  % 11 --- Set the Color
  % 12 --- Set the Linestyle
  % dismenu(number) is the callback function defined by
  % display_menu{number}, here, in
  % the array of display_menu{number}, uicontrol
  % is used to setup the control.
  
  switch argin1
    
    case 1 % SELECT WHICH PLOT NUMBER
      whichplot = get(display_menu{1},'value');
      
      % set the value of the requestnumber listbox
      if display_choices(whichplot).all_flag
	% if all_flag=1, then acqno is corresponding to 'All',
	% or one greater than the actual number of ALL downloads
	acqindex = size(all_display_data,1)+1;
      else
	acqno = display_choices(whichplot).acqno;
	acqchoices = cat(1,all_display_data(:).acqno);
	acqindex = find(acqchoices == acqno);
      end
      set(display_menu{2}, 'value', max(acqindex));
      % set the variable names listboxes(X-data,Y-data,U-data and V-data)
      h = cat(1,display_menu{5:8});
      h = h(:,2);
      if display_choices(whichplot).all_flag
	% generate a list of all names
	names = char(all_display_data(:).name);
	keepvar = [1; find(~strcmp(cellstr(names),'none'))];
	names = names(keepvar,:);
	set(h, 'string', names);
      else
	set(h, 'string', all_display_data(acqindex).name);
      end
         
      % set the plot type selection.  This will turn
      %on/off the correct axis buttons
      str = get(display_menu{10},'string');
      plot_type = strmatch(display_choices(whichplot).plot_type,lower(str),'exact');
      set(display_menu{10}, 'value', plot_type)
      switch plot_type  % set the corresponding menus in Frame 3 section
	case 1 % plot
	  set(cat(2, display_menu{[7:8 20]}),'vis','off')
          if ~display_choices(whichplot).click
	    plotinit('plotmode', whichplot);
	  end
                    
	case 2 % imagesc
	  set(display_menu{7},'vis','on')
	  set(display_menu{7}(1), 'string', 'Z-data', ...
	      'tooltip', 'Select the data to be imaged/contoured')
	  set(display_menu{8},'vis','off')
	  if ~display_choices(whichplot).click
	    plotinit('imagemode', whichplot);
	  end
                    
	case 3 % contour
	  set(display_menu{7},'vis','on')
	  set(display_menu{7}(1),'string', 'Z-data')
	  set(display_menu{8},'vis','off')
	  if ~display_choices(whichplot).click
	    plotinit('imagemode', whichplot);
	  end
                    
	case 4 % contourf
	  set(display_menu{7},'vis','on')
	  set(display_menu{7}(1), 'string', 'Z-data')
	  set(display_menu{8},'vis','off')
	  if ~display_choices(whichplot).click
	    plotinit('imagemode', whichplot);
	  end
                    
	case 5 % pcolor
	  set(display_menu{7},'vis','on')
	  set(display_menu{7}(1),'string', 'Z-data')
	  set(display_menu{8},'vis','off')
	  if ~display_choices(whichplot).click
	    plotinit('imagemode', whichplot);
	  end
                    
	case 6 % quiver
	  set(display_menu{7}, 'vis', 'on')
	  set(display_menu{7}(1), 'string', 'U-data', ...
	      'tooltip', 'Select the x-component of the data vector')
	  set(display_menu{8},'vis','on')
	  if ~display_choices(whichplot).click
	    plotinit('quivermode', whichplot);
	  end
                    
	case 7 % polar
	  set(cat(2, display_menu{[7 8]}),'vis','off')
	  if ~display_choices(whichplot).click
	    plotinit('plotmode', whichplot);
	  end
      end
           
      % set the menu values and the size strings
      whichvar = display_choices(whichplot).x;
      set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
      dispmenu('setvar', 5)
            
      whichvar = display_choices(whichplot).y;
      set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
      dispmenu('setvar', 6)
      
      whichvar = display_choices(whichplot).z;
      set(display_menu{7}(2),'value', whichvar, 'listboxtop', whichvar)
      dispmenu('setvar', 7)
           
      whichvar = display_choices(whichplot).zz;
      set(display_menu{8}(2),'value', whichvar, 'listboxtop', whichvar)
      dispmenu('setvar', 8)
      
      if plot_type == 1 | plot_type == 7
	% ONLY reset slice if the user has not clicked on
	% this plot before.  Otherwise, we chance wiping out
	% user input from the display window!
	if ~display_choices(whichplot).click
	  % This sets slice and slicesize corresponding to X-data
	  dispmenu('setnewvar',5)
	  % This sets slice and slicesize corresponding to Y-data
	  dispmenu('setnewvar',6)
	end
      else
	% ONLY reset slice if the user has not clicked on
	% this plot before.  Otherwise, we chance wiping out
	% user input from the display window!
	if ~display_choices(whichplot).click
	  % This sets slice and slicesize corresponding to Z-data
	  dispmenu('setnewvar',7)
	  % This sets slice and slicesize corresponding to ZZ-data
	  dispmenu('setnewvar',8)
	end
      end
      
      % set the special menu values in Frame 2 section Note that visibility
      % of the menu must also be toggled.
      if strcmp(display_choices(whichplot).plot_type, 'plot') | ...
	    strcmp(display_choices(whichplot).plot_type, 'polar')
	% set color menu
	dispmenu('menu11')
	% set linestyle menu
	dispmenu('menu12')
           
	% set marker menu
	dispmenu('menu13')
	set(cat(2, display_menu{14:16}),'vis','off')
	set(display_menu{20},'vis','off')  % Added by Xin Zhang
	
      elseif strcmp(display_choices(whichplot).plot_type, 'imagesc')
	% set color limits menu
	dispmenu('menu15')
	set(cat(2, display_menu{[11:14 16 20]}), 'vis', 'off')
	
      elseif strcmp(display_choices(whichplot).plot_type, 'contour') ...
	    | strcmp(display_choices(whichplot).plot_type, 'contourf')
	% set color menu
	dispmenu('menu11')
	% set linestyle menu
	dispmenu('menu12')
	% set the contour levels menu
	dispmenu('menu16')
	set(cat(2, display_menu{[13:15 20]}),'vis','off')
      elseif strcmp(display_choices(whichplot).plot_type, 'pcolor')
	% set shading menu
	dispmenu('menu14')
	% set color limits menu
	dispmenu('menu15')
	set(cat(2, display_menu{[11:13 16 20]}),'vis','off')
      elseif strcmp(display_choices(whichplot).plot_type, 'quiver')
	% set color menu
	dispmenu('menu11')
	% set linestyle menu
	dispmenu('menu12')
	% Code added by Xin Zhang  Fall 2002
	% set scale menu  
	dispmenu('menu17')
	% End of code added by Xin Zhang
	set(cat(2, display_menu{13:16}),'vis','off')
      end
      
      % set the target figure
      if isstr(display_choices(whichplot).figure)
	if strcmp(display_choices(whichplot).figure,'browse_fig')
	  set(display_menu{3},'value',1)
	  set(display_menu{4},'vis','off')
	elseif strcmp(display_choices(whichplot).figure,'figure')
	  set(display_menu{3},'value',2)
	  set(display_menu{4},'vis','off')
	end
      else
	set(display_menu{3},'value',3)
	str = num2str(display_choices(whichplot).figure);
	set(display_menu{4},'vis','on','string', str)
      end
      display_choices(whichplot).click = 1;
      
    case 2 % set the acquisition number
      whichplot = get(display_menu{1},'value');
      Rxxno = get(display_menu{2},'value');
      str = get(display_menu{2},'string');
      
      if ~isempty(instr('All',str(Rxxno,:)))   % 'All' is selected
	combo_display_name = cell(0,0);
	% The following code strips 'none' out and stores in temp_display_data	
	for i = 1:size(all_display_data,1)
	  sz = size(all_display_data(i).name,1);
	  keepvar = zeros(sz,1);
	  for j = 1:sz
	    if isempty(instr('none',all_display_data(i).name(j,:)))
	      keepvar(j) = 1;
	    end
	  end
	  combo_display_name = [combo_display_name;...
		    cellstr(all_display_data(i).name(find(keepvar),:))];
	end
          
	combo_display_name = [{'none'}; combo_display_name];
	h = cat(1,display_menu{5:8});
	h = h(:,2);
	% set the variable names listboxes(X-data,Y-data,U-data and V-data)
	set(h, 'string', combo_display_name);
	% if All is selected, all the default slices in X-data,Y-data
	set(display_menu{5}(2), 'value', 1);
	set(display_menu{6}(2), 'value', 1);  % U-data and V-data are none
	set(display_menu{7}(2), 'value', 1);
	set(display_menu{8}(2), 'value', 1);
	% call dispmenu('setnewvar',[x]) to refresh the slice and
	% slice size corresponding to listbox          
	dispmenu('setnewvar',5)
	dispmenu('setnewvar',6)   % of dispmenu{5-8}
	dispmenu('setnewvar',7)
	dispmenu('setnewvar',8)
	display_choices(whichplot).all_flag = 1;
                   
      else  % 'All' is not selected
	
	str = deblank(str(Rxxno,:));
	% string begins with 'R' and ends with '_'
	% strip these out.
	str = str(2:length(str)-1);
	acqno = str2num(str);
	acqchoices = cat(1,all_display_data(:).acqno);
	acqindex = find(acqchoices == acqno);
                                
	whichvar = display_choices(whichplot).x;
	sz = size(all_display_data(acqindex).name,1);
	newval = min([sz whichvar]);
	set(display_menu{5}(2), 'value', newval, ...
		  'listboxtop', newval, ...
		  'string', all_display_data(acqindex).name)
	dispmenu('setnewvar', 5)

	whichvar = display_choices(whichplot).y;
	sz = size(all_display_data(acqindex).name,1);
	newval = min([sz whichvar]);
	set(display_menu{6}(2), 'value', newval, ...
		  'listboxtop', newval, ...
		  'string', all_display_data(acqindex).name)
	dispmenu('setnewvar', 6)

	whichvar = display_choices(whichplot).z;
	sz = size(all_display_data(acqindex).name,1);
	newval = min([sz whichvar]);
	set(display_menu{7}(2), 'value', newval, ...
		  'listboxtop', newval, ...
		  'string', all_display_data(acqindex).name)
	
	whichvar = display_choices(whichplot).zz;
	sz = size(all_display_data(acqindex).name,1);
	newval = min([sz whichvar]);
	set(display_menu{8}(2), 'value', newval, ...
		  'listboxtop', newval, ...
		  'string', all_display_data(acqindex).name)
	
	% cannot set this before now or "isall" in "setnewvar" misfires
	display_choices(whichplot).all_flag = 0;
	display_choices(whichplot).acqno = acqno;
          
	plot_type = get(display_menu{10},'value');
	switch plot_type
	  case 1
	    plotinit('plotmode', whichplot);
	  case 2
	    plotinit('imagemode', whichplot);
	  case 3
	    plotinit('imagemode', whichplot);
	  case 4
	    plotinit('imagemode', whichplot);
	  case 5
	    plotinit('imagemode', whichplot);
	  case 6
	    plotinit('quivermode', whichplot);
	  case 7
	    plotinit('plotmode', whichplot);
	end
          
	whichvar = display_choices(whichplot).x;
	set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
	dispmenu('setvar', 5)
           
	whichvar = display_choices(whichplot).y;
	set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
	dispmenu('setvar', 6)
           
	whichvar = display_choices(whichplot).z;
	set(display_menu{7}(2),'value', whichvar, 'listboxtop', whichvar)
	dispmenu('setvar', 7)
           
	whichvar = display_choices(whichplot).zz;
	set(display_menu{8}(2),'value', whichvar, 'listboxtop', whichvar)
	dispmenu('setvar', 8)   
           
	if plot_type == 1 | plot_type == 7
	  % This is only to set slice and slicesize corresponding to X-data
	  dispmenu('setnewvar',5)
	  % This is only to set slice and slicesize corresponding to Y-data
	  dispmenu('setnewvar',6)
	else
	  % This is only to set slice and slicesize corresponding to U-data
	  dispmenu('setnewvar',7)
	  % This is only to set slice and slicesize corresponding to V-data
	  dispmenu('setnewvar',8)
	end
      end  % end of if all_flag
      
    case 3
      % SET THE FIGURE SELECTION FOR THIS PLOT        
      whichplot = get(display_menu{1},'value');
      val = get(display_menu{3},'value');
      if val == 1
	set(display_menu{4},'vis','off')
	display_choices(whichplot).figure = 'browse_fig';
      elseif val == 2
	set(display_menu{4},'vis','off')
	display_choices(whichplot).figure = 'figure';
      elseif val == 3
	display_choices(whichplot).figure = 'figure';
	set(display_menu{4},'vis','on', 'string', '')
      end
    
    case 4
      whichplot = get(display_menu{1},'value');
      if get(display_menu{3},'value') == 3
	figno = get(display_menu{4},'string');
	figno = sscanf(figno, '%i');
	if ~isempty(figno)
	  display_choices(whichplot).figure = figno;
	else
	  % automatically dump to new figure
	  display_choices(whichplot).figure = 'figure';
	end
      end
    
    case 5
      % GET THE SELECTED X VARIABLE
      dispmenu('setnewvar', argin1)
      plot_type = get(display_menu{10},'value');
        
      switch plot_type
	case 1
	  % plot
	case 2
	  % imagesc
	  % refresh U-data listbox when you reset any slice in X-data
	  % listbox,  modified by Xin Zhang Oct. 2002	  
	  dispmenu(7)
	case 3
	  % contour
	  dispmenu(7)
	case 4
	  % contourf
	  dispmenu(7)
	case 5
	  % pcolor
	  dispmenu(7)
	case 6
	  % quiver
	  % refresh V-data listbox when you reset any slice in X-data
	  % listbox,  modified by Xin Zhang Oct. 2002	  
	  dispmenu(7)
	  dispmenu(8)
	case 7
	  % polar
      end
    
    case 6
      % DISPLAY THE SELECTED Y VARIABLE
      dispmenu('setnewvar', argin1)
      plot_type = get(display_menu{10},'value');
      switch plot_type
	case 1
	case 2
	  % refresh U-data listbox when you reset any slice in X-data
	  % listbox,  modified by Xin Zhang Oct. 2002
	  dispmenu(7)
	case 3
	  dispmenu(7)
	case 4
	  dispmenu(7)
	case 5
	  dispmenu(7)
	case 6
	  % refresh V-data listbox when you reset any slice in X-data
	  % listbox,  modified by Xin Zhang Oct. 2002
	  dispmenu(7)
	  dispmenu(8)
	case 7
      end
    
    case 7
      % DISPLAY THE SELECTED Z VARIABLE
      dispmenu('setnewvar', argin1)
    
    case 8
      % DISPLAY THE SELECTED ZZ VARIABLE
      dispmenu('setnewvar', argin1)

    case 9
      % case 9 is not used at this point.
    
    case 10
      % RESET THE PLOT TYPE FOR THIS PLOT
      whichplot = get(display_menu{1},'value');
      plot_type = get(display_menu{10},'value');
      str = get(display_menu{10},'string');
      
      % save the plot type
      display_choices(whichplot).plot_type = ...
	  deblank(lower(str(plot_type,:)));
      
      % reset all plot type options to their defaults
      display_choices(whichplot).color = 'k';
      display_choices(whichplot).scale = 1;
      display_choices(whichplot).linestyle = '-';
      display_choices(whichplot).marker = '.';
      display_choices(whichplot).shading = 'flat';
      display_choices(whichplot).clim = [];
      display_choices(whichplot).cval = [];
      
      switch plot_type
	case 1
	  % plot
	  set(cat(2, display_menu{[7 8]}),'vis','off')
	  % set the special menus
	  set(display_menu{11}(1), 'vis', 'on', 'val', 1)
          set(display_menu{11}(2),'vis','on')
          set(display_menu{12}(1), 'vis', 'on', 'val', 1)
          set(display_menu{12}(2),'vis','on')
          set(display_menu{13}(1),'vis', 'on', 'val', 1)
          set(display_menu{13}(2),'vis','on')
          set(display_menu{20}(1),'vis','off')
          set(display_menu{20}(2),'vis','off')
          set(display_menu{14},'vis','off')
          set(display_menu{15},'vis','off')
          set(display_menu{16},'vis','off')
          set(display_menu{9}(3:4),'enable','off')
          % Initialize the slice in X-data and Y-data windows for
          % plot ONLY if the Rxx number is not 'All'.
	  if display_choices(whichplot).all_flag == 0
	    plotinit('plotmode', whichplot);
	    whichvar = display_choices(whichplot).x;
	    set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 5)    % Set slice in X-data
	    whichvar = display_choices(whichplot).y;
	    set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 6)    % Set slice in Y-data
	    dispmenu('setnewvar',5)  % Set slicesize in X-data
	    dispmenu('setnewvar',6)  % Set slicesize in Y-data
	  end
	  % Set plot info including Color, Linestyle, Marker and Displayfigure
          dispmenu('setplotinfo',1)
          
	case 2
	  % imagesc	  
	  set(display_menu{7},'vis','on')
          set(display_menu{7}(1), 'string', 'Z-data', ...
	      'tooltip', 'Select the data to be imaged/contoured')
      	  set(display_menu{8},'vis','off')
          % set the special menus
          set(cat(2,display_menu{[11:14 20]}),'vis','off')
          set(display_menu{15}(1),'vis','on','string', '')
          set(display_menu{15}(2),'vis','on')
          set(display_menu{16},'vis','off')
          set(display_menu{9}(3),'enable','on','label','Set Z-data')
          set(display_menu{9}(4),'enable','off')
          % Initialize the slice in X-data, Y-data and Z-data for imagesc
	  if display_choices(whichplot).all_flag == 0
	    plotinit('imagemode', whichplot);     % Added by Xin  Nov. 30 2002
	    whichvar = display_choices(whichplot).x;
	    set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 5)
	    whichvar = display_choices(whichplot).y;
	    set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 6)
	    whichvar = display_choices(whichplot).z;
	    set(display_menu{7}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 7)    % Set slice in Z-data
	    dispmenu('setnewvar',7)  % Set slicesize in Z-data
	  end
          dispmenu('setplotinfo',2)
      	  
	case 3
	  % contour
          set(display_menu{7},'vis','on')
          set(display_menu{7}(1),'string', 'Z-data')
          set(display_menu{8},'vis','off')
          % set the special menus
          set(display_menu{11}(1),'vis', 'on', 'value', 1)
          set(display_menu{11}(2),'vis','on')
          set(display_menu{12}(1),'vis', 'on', 'value', 1)
          set(display_menu{12}(2),'vis','on')
          set(display_menu{13},'vis','off')
          set(display_menu{14},'vis','off')
          set(display_menu{15},'vis','off')
          set(display_menu{16}(1),'vis', 'on', 'string', '')
          set(display_menu{16}(2),'vis','on')
          set(display_menu{9}(3),'enable','on','label','Set Z-data')
          set(display_menu{9}(4),'enable','off')
          set(display_menu{20}(1),'vis', 'off')
          set(display_menu{20}(2),'vis', 'off')
          % Initialize the slice in X-data, Y-data and Z-data for contour
	  if display_choices(whichplot).all_flag == 0
	    plotinit('imagemode', whichplot); % Added by Xin Nov. 30  2002
	    whichvar = display_choices(whichplot).x;
	    set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 5)
	    whichvar = display_choices(whichplot).y;
	    set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 6)
	    whichvar = display_choices(whichplot).z;
	    set(display_menu{7}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 7)
	    dispmenu('setnewvar',7)
	  end
          dispmenu('setplotinfo',3)
      
	case 4
	  % contourf
          set(display_menu{7},'vis','on')
          set(display_menu{7}(1), 'string', 'Z-data')
          set(display_menu{8},'vis','off')
          % set the special menus
          set(display_menu{11}(1),'vis', 'on', 'value', 1)
          set(display_menu{11}(2),'vis','on')
          set(display_menu{12}(1),'vis','on', 'value', 1)
          set(display_menu{12}(2),'vis','on')
          set(display_menu{13},'vis','off')
          set(display_menu{14},'vis','off')
          set(display_menu{15},'vis','off')
          set(display_menu{16}(1),'vis', 'on', 'string', '')
          set(display_menu{16}(2),'vis','on')
          set(display_menu{9}(3),'enable','on','label','Set Z-data')
          set(display_menu{9}(4),'enable','off')
          set(display_menu{20}(1),'vis', 'off')
          set(display_menu{20}(2),'vis', 'off')
          % Initialize the slice in X-data, Y-data and Z-data for contourf
	  if display_choices(whichplot).all_flag == 0
	    plotinit('imagemode', whichplot);
	    whichvar = display_choices(whichplot).x;
	    set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 5)   % Init slice in X-data
	    whichvar = display_choices(whichplot).y;
	    set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 6)   % Init slice in Y-data
	    whichvar = display_choices(whichplot).z;
	    set(display_menu{7}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 7)   % Init slice in Z-data
	    dispmenu('setnewvar',7) 
	  end
          dispmenu('setplotinfo',4)
          	  
	case 5
	  % pcolor
          set(display_menu{7},'vis','on')
	  set(display_menu{7}(1),'string', 'Z-data')
	  set(display_menu{8},'vis','off')
	  % set the special menus
	  set(cat(2, display_menu{[11:13 20]}),'vis','off')
	  set(display_menu{14}(1),'vis','on', 'value', 1)
	  set(display_menu{14}(2),'vis','on')
	  set(display_menu{15}(1),'vis','on','string', '')
	  set(display_menu{15}(2),'vis','on')
	  set(display_menu{16},'vis','off')
	  set(display_menu{9}(3),'enable','on','label','Set Z-data')
	  set(display_menu{9}(4),'enable','off')
	  set(display_menu{20}(1),'vis','off')
          set(display_menu{20}(2),'vis','off')
          % Initialize the slice in X-data, Y-data and Z-data for pcolor
	  if display_choices(whichplot).all_flag == 0
	    plotinit('imagemode', whichplot);
	    whichvar = display_choices(whichplot).x;
	    set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 5)
	    whichvar = display_choices(whichplot).y;
	    set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 6)
	    whichvar = display_choices(whichplot).z;
	    set(display_menu{7}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 7)
	    dispmenu('setnewvar',7)
	  end
          dispmenu('setplotinfo',5)
      
	case 6
	  % quiver
	  set(display_menu{7}, 'vis', 'on')
	  set(display_menu{7}(1), 'string', 'U-data', ...
	      'tooltip', 'Select the x-component of the data vector')
	  set(display_menu{8},'vis','on')
	  % set the special menus
	  set(display_menu{20}(1),'vis','on', 'value', 1)   % Added by Xin Zhang
	  set(display_menu{20}(2),'vis','on')
	  set(display_menu{11}(1),'vis', 'on', 'value', 1)
	  set(display_menu{11}(2),'vis','on')
	  set(display_menu{12},'vis', 'on', 'value', 1)
	  set(display_menu{12}(2),'vis','on')
	  set(display_menu{13},'vis', 'off')
	  set(display_menu{14},'vis','off')
	  set(display_menu{15},'vis','off')
	  set(display_menu{16},'vis','off')
	  set(display_menu{9}(3),'enable','on','label','Set U-data')
	  set(display_menu{9}(4),'enable','on')
          % Initialize the slice in X-data, Y-data, U-data and
          % V-data for quiver
	  if display_choices(whichplot).all_flag == 0
	    plotinit('quivermode', whichplot);
	    whichvar = display_choices(whichplot).x;
	    set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 5)
	    whichvar = display_choices(whichplot).y;
	    set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 6)
	    whichvar = display_choices(whichplot).z;
	    set(display_menu{7}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 7)
	    whichvar = display_choices(whichplot).zz;
	    set(display_menu{8}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 8)
	    dispmenu('setnewvar',7)
	    dispmenu('setnewvar',8)
	  end
          dispmenu('setplotinfo',6)
          
	case 7
	  % polar
          set(cat(2, display_menu{[7 8]}),'vis','off')
          % set the special menus
          set(display_menu{11}(1), 'vis', 'on', 'val', 1)
          set(display_menu{11}(2),'vis','on')
          set(display_menu{12}(1), 'vis', 'on', 'val', 1)
          set(display_menu{12}(2),'vis','on')
          set(display_menu{13}(1),'vis', 'on', 'val', 1)
          set(display_menu{13}(2),'vis','on')
          set(display_menu{14},'vis','off')
          set(display_menu{15},'vis','off')
          set(display_menu{16},'vis','off')
          set(display_menu{9}(3:4),'enable','off')
          set(display_menu{20}(1:2),'vis','off')
          % Initialize the slice in X-data, Y-data, U-data and V-data for quiver
	  if display_choices(whichplot).all_flag == 0
	    plotinit('plotmode', whichplot);
	    whichvar = display_choices(whichplot).x;
	    set(display_menu{5}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 5)
	    whichvar = display_choices(whichplot).y;
	    set(display_menu{6}(2),'value', whichvar, 'listboxtop', whichvar)
	    dispmenu('setvar', 6)
	    dispmenu('setnewvar',5)  % Set slicesize in X-data
	    dispmenu('setnewvar',6)  % Set slicesize in Y-data
	  end
          dispmenu('setplotinfo',7)
      end

    case 11
      % SET THE COLOR        
      whichplot = get(display_menu{1},'value');
      val = get(display_menu{11}(1),'value');
      str = get(display_menu{11}(1),'string');
      color = deblank(str(val,:));
      if strcmp(color,'default'), color = ''; end
      display_choices(whichplot).color = color;
      
    case 12
      % SET THE LINESTYLE        
      whichplot = get(display_menu{1},'value');
      val = get(display_menu{12}(1),'value');
      str = get(display_menu{12}(1),'string');
      linestyle = deblank(str(val,:));
      if strcmp(linestyle,'none'), linestyle = ''; end
      display_choices(whichplot).linestyle = linestyle;
      
    case 13
      % SET THE PLOT MARKER        
      whichplot = get(display_menu{1},'value');
      val = get(display_menu{13}(1),'value');
      str = get(display_menu{13}(1),'string');
      marker = deblank(str(val,:));
      if strcmp(marker,'none'), marker = ''; end
      display_choices(whichplot).marker = marker;
            
    case 14
      % SET THE SHADING TYPE        
      whichplot = get(display_menu{1},'value');
      val = get(display_menu{14}(1),'value');
      str = get(display_menu{14}(1),'string');
      display_choices(whichplot).shading = deblank(str(val,:));
      
    case 15
      % SET COLOR LIMITS FOR THIS PLOT        
      whichplot = get(display_menu{1},'value');
      str = get(display_menu{15}(1),'string');
      color_limits = sscanf(str,'%f');
      if all(sort(size(color_limits)) == [1 2])
	color_limits = color_limits(:)';
      else
	color_limits = [];
      end
      display_choices(whichplot).clim = color_limits;
      
    case 16
      whichplot = get(display_menu{1},'value');
      str = get(display_menu{16}(1),'string');
      eval([ 'cval = [' str '];']);
      display_choices(whichplot).cval = cval;
      
    case 17
      % PLOT SELECTED BUTTON      
      whichplot = get(display_menu{1},'value');
      browse('enableclear')
      plotfunction(display_choices, all_display_data, whichplot)
      return 
          
    case 18
      % CANCEL BUTTON        
      set(display_fig, 'visible', 'off')
      browse('getdata','cancel')
      return
      
    case 19
      % PLOT ALL BUTTON        
      browse('enableclear')
      plotfunction(display_choices, all_display_data)
      return
      
    case 20
      %  SET THE SCALE        
      % Code added by Xin Zhang  
      whichplot = get(display_menu{1},'value');
      str = get(display_menu{20}(1),'string');
      scale = sscanf(str,'%f');
      display_choices(whichplot).scale = scale;
  end % end of switch

end % end of checking for argin1 is string or not
