function outname = dods_dbk(inname)

% dods_dbk: translate URL fieldnames for the NVODS Matlab GUI.
% Original fieldnames will be transformed into names as they will
% appear in Matlab.  Completely rewritten 2004/04/28 by dbyrne.

if isempty(inname)
  outname = '';
  return
end

% some characters not allowed in Matlab variables
replace_chars = [...
{' ', '20';...
'!', '21';...
'"', '22';...
'#', '23';...
'$', '24';...
'%', '25';...
'&', '26';...
'''', '27';...
'(', '28';...
')', '29';...
'*', '2a';...
'+', '2b';...
',', '2c';...
'-', '2d';...
'.', '2e';...
'/', '2f';...
':', '3a';...
';', '3b';...
'<', '3c';...
'=', '3d';...
'>', '3e';...
'?', '3f';...
'[', '5b';...
'\', '5c';...
']', '5d';...
'^', '5e';...
'`', '60';...
'{', '7b';...
'|', '7c';...
'}', '7d';...
'~', '7e';...
'@', '40'}];


% NEW 2003/05/19  Check matlab version.
v = checkver;
% the current name length limit: Release 13 -- dbyrne 2003/04/30
if v >= 6.5
  namelimit = 63;
else
  % the previous name length limit.  This change could cause serious
  % problems for users with different versions of Matlab!
  namelimit = 31;
end

tmpname = deblank(inname);
tmpname = fliplr(deblank(fliplr(tmpname)));

for i = 1:size(replace_chars,1)
  if strcmp(tmpname(1),replace_chars{i,1});
    tmpname = [ 'ml_' tmpname];
  end
  tmpname = strrep(tmpname,replace_chars{i,1}, ['_' replace_chars{i,2}]);
end
if length(tmpname) > namelimit
  tmpname = tmpname(1:namelimit);
end
outname = tmpname;
return
