function squeezeslice = setsqueeze(argin1,argin2,argin3)

% squeezeslice function is used to set slice in U-data and V-data edit box
% The slice in U-data or V-data edit box is set with respect to the
% slices already set in X-data and Y-data listbox
% transpose may need when (1) slice in Y-data listbox is not
% Rx_latitude(any of Longitude and Latitude is present in X-data or
% Y-data listbox)
% or (2) no Longitude and Latitude in X-data and Y-data listbox, but
% the slice in Y-data listbox is not Depth 

%        Written by Xin Zhang  Oct. 2002  University of Rhode Island
%        zhangxin@ele.uri.edu


global all_display_metadata all_display_data display_choices

whichvar = argin1;
whichplot = argin2;
acqindex = argin3;

geopos_string = str2mat('Longitude', 'Latitude', 'Depth', 'Time');
squeezeslice = [];
% check that metadata exists
index = all_display_data(acqindex).index;
geopos = all_display_metadata{index}.geopos;

if any(geopos)
  % check that metatdata is not empty or incorrectly sized
  if all(size(geopos) == [1 4])
    % check that lat and lon maps are identified in metadata
    if (geopos(1) > 0) & (geopos(2) > 0)
      % get the number of dimensions
      ND = size(all_display_metadata{index}.axes,1);
      % now go ahead and create a slice
      slice = deblank(all_display_data(acqindex).name(whichvar,:));
      if ND > 2
	% create a 2-D slice
	slice = [slice '(' ];
	
	for i = 1:ND   % Setup a string as 1,1,1,
	  % the total number of 1's in this string == ND
	  squeeze_string(i) = '1';
	end
	
	for l = 1:ND
	  var = display_choices(whichplot).x;
	  [temp, temp, varname] = isall('set', whichplot, var);
	  for i = 1:4
	    if ~isempty(instr(deblank(geopos_string(i,:)),varname))
	      if geopos(i) > 0
		squeeze_string(geopos(i)) = ':';
	      else
		str = sprintf('Error: No %s in this database!', ...
		    deblank(geopos_string(i,:)));
		dodsmsg(str)
		return
	      end
	    end  % end if
	  end % end of for-loop
	  
	  var = display_choices(whichplot).y;
	  [temp, temp, varname] = isall('set', whichplot, var);
	  for i = 1:4
	    if ~isempty(instr(deblank(geopos_string(i,:)),varname))
	      if geopos(i) > 0
		squeeze_string(geopos(i)) = ':';
	      else
		str = sprintf('Error: No %s in this database!', ...
		    deblank(geopos_string(i,:)));
		dodsmsg(str)
		return
	      end
	    end  % end if
	  end % end of for-loop
	  
	end % end of for l = 1:ND
	
	for i = 1:ND  % Add commas to squeeze_string
	  if i < ND
	    squeeze_string_comma(i*2-1)   = squeeze_string(i);
	    squeeze_string_comma(i*2) = ',';
	  else
	    squeeze_string_comma(i*2-1)  = squeeze_string(i);
	  end
	end
	slice = [slice squeeze_string_comma];
	squeezeslice = [ 'squeeze(' slice '))'];
      end   % end of if ND > 2
    end % end of geopos value check
  end % end of geopos size check
end  % end of metadata exist check
return
