% UNPACK  Part of the NVODS data browser (browse.m)
%
%            Deirdre Byrne, University of Maine, 21 Dec 2000
%                 dbyrne@umeoce.maine.edu
%

% if nothing came back, clean up and quit
if exist('browse_count') ~= 1 | exist('browse_acq_urls') ~= 1
  clrvars
  return
end

% or if the number of urls is undefined or is 0, clean up and quit
if browse_acq_urls == 0;
  if isempty(browse_count)
    clrvars
    return
  end
end

% NOTE: In following code we go 1 past the number of URLs expected
% because an aborted request will still have returned a URL and nothing
% else.  Hence the limit browse_acq_urls+1

% First find out what variables have been returned.
for browse_i = 1:browse_acq_urls+1
  browse_j = browse_count+browse_i-1;
  browse_string = sprintf('browse_w = whos(''R%i_*'');', browse_j);
  eval(browse_string);
  if ~isempty(browse_w)
    browse_whos(browse_i).name = char(browse_w.name);
    browse_k = cell(size(browse_w));
    [browse_k{:}] = deal(browse_w.size);
    browse_whos(browse_i).size = browse_k;
  end
end
browse_whos = browse_whos(:);

% if the ONLY things that have been returned are
% Acknowledge and URL, the data request was not successful
for browse_i = 1:size(browse_whos,1)
  browse_j = browse_count+browse_i-1;
  if size(browse_whos(browse_i).name,1) == 1
    if strcmp(deblank(browse_whos(browse_i).name(1,:)), ...
	      sprintf('R%i_Acknowledge',browse_j)) | ...
	  strcmp(deblank(browse_whos(browse_i).name(1,:)), ...
		 sprintf('R%i_URL',browse_j))
      browse_whos(browse_i).size = {0};
    end
  elseif size(browse_whos(browse_i).name,1) == 2
    if strcmp(deblank(browse_whos(browse_i).name(1,:)), ...
	      sprintf('R%i_Acknowledge',browse_j)) & ...
	  strcmp(deblank(browse_whos(browse_i).name(2,:)), ...
		 sprintf('R%i_URL',browse_j))
      browse_whos(browse_i).size = [{0}; {0}];
    end
  end
end

% Find any variables that are empty
browse_data_list = ''; 
for browse_i = 1:size(browse_whos,1)
  browse_sz = size(browse_whos(browse_i).size,1);
  browse_empty = zeros(browse_sz,1);
  for browse_j = 1:browse_sz
    if any(browse_whos(browse_i).size{browse_j} == 0)
      browse_empty(browse_j) = 1;
    end
  end

  % Delete them from the workspace and update the variables database
  if any(browse_empty)
    browse_k = cellstr(browse_whos(browse_i).name(find(browse_empty),:));
    eval(['clear ' sprintf('%s ',browse_k{:})]);
    browse_whos(browse_i).name = ...
	browse_whos(browse_i).name(find(~browse_empty),:);
    browse_whos(browse_i).size = ...
	browse_whos(browse_i).size(find(~browse_empty),:);
  end
end

% if no data, exit cleanly
if isempty(strvcat(browse_whos(:).name))
  dodsmsg('This request generated no data')
  if browse_count > 1
    browse('enableclear');
  end
  clrvars
  return
else
  % terminate to true number of URLs
  browse_whos = browse_whos(1:browse_acq_urls);
  if isempty(browse_whos)
    if browse_count > 1
      browse('enableclear');
    end
    clrvars
    return
  end
end

% show the user what variables have been put in the workspace:
browse_string2 = sprintf('R%i_   ', ...
    browse_count:browse_count+browse_acq_urls-1);
browse_string = sprintf('\n%s%i%s\n%s%s','This request generated ',  ...
    browse_acq_urls, ' separate URLs, ', ...
    'which are stored in the sets:  ', ...
    browse_string2);
browse_string = sprintf('%s\n\n%s\n', ...
    browse_string, ...
    'Each individual argument is stored like so:');

browse_string2 = cellstr(cat(1,browse_whos(1).name));
browse_string = sprintf('%s\n%s\n', browse_string, ...
    browse_string2{:});
dodsmsg(browse_string)

% display the plot menu

%   Plot menu input arguments:
%   browse_metadata: a struct with ONE entry per data request, no
%   matter how many URLs satisfied that request

%   browse_whos: a struct with names of the downloaded variables,
%   which ONE for EACH URL

%   browse_count: the Rxx number of the first URL in the request

%   browse_getvariables: the name of the user-selected variables
%   from the variable list (not the name from the dataset) e.g., Sea_temp
dispmenu('display', browse_whos, browse_getvariables, browse_count, ...
    browse_metadata)

% allow user to clear downloaded stuff
browse('enableclear')

% clean up the user workspace
clrvars
